// Copyright 2026 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.11
// 	protoc        v6.33.2
// source: google/cloud/kms/v1/service.proto

package kmspb

import (
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"

	longrunningpb "cloud.google.com/go/longrunning/autogen/longrunningpb"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	_ "google.golang.org/protobuf/types/known/emptypb"
	fieldmaskpb "google.golang.org/protobuf/types/known/fieldmaskpb"
	wrapperspb "google.golang.org/protobuf/types/known/wrapperspb"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

// Request message for
// [KeyManagementService.ListKeyRings][google.cloud.kms.v1.KeyManagementService.ListKeyRings].
type ListKeyRingsRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the location associated with the
	// [KeyRings][google.cloud.kms.v1.KeyRing], in the format
	// `projects/*/locations/*`.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Optional. Optional limit on the number of
	// [KeyRings][google.cloud.kms.v1.KeyRing] to include in the response. Further
	// [KeyRings][google.cloud.kms.v1.KeyRing] can subsequently be obtained by
	// including the
	// [ListKeyRingsResponse.next_page_token][google.cloud.kms.v1.ListKeyRingsResponse.next_page_token]
	// in a subsequent request.  If unspecified, the server will pick an
	// appropriate default.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Optional. Optional pagination token, returned earlier via
	// [ListKeyRingsResponse.next_page_token][google.cloud.kms.v1.ListKeyRingsResponse.next_page_token].
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// Optional. Only include resources that match the filter in the response. For
	// more information, see
	// [Sorting and filtering list
	// results](https://cloud.google.com/kms/docs/sorting-and-filtering).
	Filter string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
	// Optional. Specify how the results should be sorted. If not specified, the
	// results will be sorted in the default order.  For more information, see
	// [Sorting and filtering list
	// results](https://cloud.google.com/kms/docs/sorting-and-filtering).
	OrderBy       string `protobuf:"bytes,5,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListKeyRingsRequest) Reset() {
	*x = ListKeyRingsRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListKeyRingsRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListKeyRingsRequest) ProtoMessage() {}

func (x *ListKeyRingsRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListKeyRingsRequest.ProtoReflect.Descriptor instead.
func (*ListKeyRingsRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{0}
}

func (x *ListKeyRingsRequest) GetParent() string {
	if x != nil {
		return x.Parent
	}
	return ""
}

func (x *ListKeyRingsRequest) GetPageSize() int32 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListKeyRingsRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

func (x *ListKeyRingsRequest) GetFilter() string {
	if x != nil {
		return x.Filter
	}
	return ""
}

func (x *ListKeyRingsRequest) GetOrderBy() string {
	if x != nil {
		return x.OrderBy
	}
	return ""
}

// Request message for
// [KeyManagementService.ListCryptoKeys][google.cloud.kms.v1.KeyManagementService.ListCryptoKeys].
type ListCryptoKeysRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the [KeyRing][google.cloud.kms.v1.KeyRing]
	// to list, in the format `projects/*/locations/*/keyRings/*`.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Optional. Optional limit on the number of
	// [CryptoKeys][google.cloud.kms.v1.CryptoKey] to include in the response.
	// Further [CryptoKeys][google.cloud.kms.v1.CryptoKey] can subsequently be
	// obtained by including the
	// [ListCryptoKeysResponse.next_page_token][google.cloud.kms.v1.ListCryptoKeysResponse.next_page_token]
	// in a subsequent request.  If unspecified, the server will pick an
	// appropriate default.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Optional. Optional pagination token, returned earlier via
	// [ListCryptoKeysResponse.next_page_token][google.cloud.kms.v1.ListCryptoKeysResponse.next_page_token].
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// The fields of the primary version to include in the response.
	VersionView CryptoKeyVersion_CryptoKeyVersionView `protobuf:"varint,4,opt,name=version_view,json=versionView,proto3,enum=google.cloud.kms.v1.CryptoKeyVersion_CryptoKeyVersionView" json:"version_view,omitempty"`
	// Optional. Only include resources that match the filter in the response. For
	// more information, see
	// [Sorting and filtering list
	// results](https://cloud.google.com/kms/docs/sorting-and-filtering).
	Filter string `protobuf:"bytes,5,opt,name=filter,proto3" json:"filter,omitempty"`
	// Optional. Specify how the results should be sorted. If not specified, the
	// results will be sorted in the default order. For more information, see
	// [Sorting and filtering list
	// results](https://cloud.google.com/kms/docs/sorting-and-filtering).
	OrderBy       string `protobuf:"bytes,6,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListCryptoKeysRequest) Reset() {
	*x = ListCryptoKeysRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListCryptoKeysRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListCryptoKeysRequest) ProtoMessage() {}

func (x *ListCryptoKeysRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListCryptoKeysRequest.ProtoReflect.Descriptor instead.
func (*ListCryptoKeysRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{1}
}

func (x *ListCryptoKeysRequest) GetParent() string {
	if x != nil {
		return x.Parent
	}
	return ""
}

func (x *ListCryptoKeysRequest) GetPageSize() int32 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListCryptoKeysRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

func (x *ListCryptoKeysRequest) GetVersionView() CryptoKeyVersion_CryptoKeyVersionView {
	if x != nil {
		return x.VersionView
	}
	return CryptoKeyVersion_CRYPTO_KEY_VERSION_VIEW_UNSPECIFIED
}

func (x *ListCryptoKeysRequest) GetFilter() string {
	if x != nil {
		return x.Filter
	}
	return ""
}

func (x *ListCryptoKeysRequest) GetOrderBy() string {
	if x != nil {
		return x.OrderBy
	}
	return ""
}

// Request message for
// [KeyManagementService.ListCryptoKeyVersions][google.cloud.kms.v1.KeyManagementService.ListCryptoKeyVersions].
type ListCryptoKeyVersionsRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKey][google.cloud.kms.v1.CryptoKey] to list, in the format
	// `projects/*/locations/*/keyRings/*/cryptoKeys/*`.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Optional. Optional limit on the number of
	// [CryptoKeyVersions][google.cloud.kms.v1.CryptoKeyVersion] to include in the
	// response. Further [CryptoKeyVersions][google.cloud.kms.v1.CryptoKeyVersion]
	// can subsequently be obtained by including the
	// [ListCryptoKeyVersionsResponse.next_page_token][google.cloud.kms.v1.ListCryptoKeyVersionsResponse.next_page_token]
	// in a subsequent request. If unspecified, the server will pick an
	// appropriate default.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Optional. Optional pagination token, returned earlier via
	// [ListCryptoKeyVersionsResponse.next_page_token][google.cloud.kms.v1.ListCryptoKeyVersionsResponse.next_page_token].
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// The fields to include in the response.
	View CryptoKeyVersion_CryptoKeyVersionView `protobuf:"varint,4,opt,name=view,proto3,enum=google.cloud.kms.v1.CryptoKeyVersion_CryptoKeyVersionView" json:"view,omitempty"`
	// Optional. Only include resources that match the filter in the response. For
	// more information, see
	// [Sorting and filtering list
	// results](https://cloud.google.com/kms/docs/sorting-and-filtering).
	Filter string `protobuf:"bytes,5,opt,name=filter,proto3" json:"filter,omitempty"`
	// Optional. Specify how the results should be sorted. If not specified, the
	// results will be sorted in the default order. For more information, see
	// [Sorting and filtering list
	// results](https://cloud.google.com/kms/docs/sorting-and-filtering).
	OrderBy       string `protobuf:"bytes,6,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListCryptoKeyVersionsRequest) Reset() {
	*x = ListCryptoKeyVersionsRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListCryptoKeyVersionsRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListCryptoKeyVersionsRequest) ProtoMessage() {}

func (x *ListCryptoKeyVersionsRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListCryptoKeyVersionsRequest.ProtoReflect.Descriptor instead.
func (*ListCryptoKeyVersionsRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{2}
}

func (x *ListCryptoKeyVersionsRequest) GetParent() string {
	if x != nil {
		return x.Parent
	}
	return ""
}

func (x *ListCryptoKeyVersionsRequest) GetPageSize() int32 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListCryptoKeyVersionsRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

func (x *ListCryptoKeyVersionsRequest) GetView() CryptoKeyVersion_CryptoKeyVersionView {
	if x != nil {
		return x.View
	}
	return CryptoKeyVersion_CRYPTO_KEY_VERSION_VIEW_UNSPECIFIED
}

func (x *ListCryptoKeyVersionsRequest) GetFilter() string {
	if x != nil {
		return x.Filter
	}
	return ""
}

func (x *ListCryptoKeyVersionsRequest) GetOrderBy() string {
	if x != nil {
		return x.OrderBy
	}
	return ""
}

// Request message for
// [KeyManagementService.ListImportJobs][google.cloud.kms.v1.KeyManagementService.ListImportJobs].
type ListImportJobsRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the [KeyRing][google.cloud.kms.v1.KeyRing]
	// to list, in the format `projects/*/locations/*/keyRings/*`.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Optional. Optional limit on the number of
	// [ImportJobs][google.cloud.kms.v1.ImportJob] to include in the response.
	// Further [ImportJobs][google.cloud.kms.v1.ImportJob] can subsequently be
	// obtained by including the
	// [ListImportJobsResponse.next_page_token][google.cloud.kms.v1.ListImportJobsResponse.next_page_token]
	// in a subsequent request. If unspecified, the server will pick an
	// appropriate default.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Optional. Optional pagination token, returned earlier via
	// [ListImportJobsResponse.next_page_token][google.cloud.kms.v1.ListImportJobsResponse.next_page_token].
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// Optional. Only include resources that match the filter in the response. For
	// more information, see
	// [Sorting and filtering list
	// results](https://cloud.google.com/kms/docs/sorting-and-filtering).
	Filter string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
	// Optional. Specify how the results should be sorted. If not specified, the
	// results will be sorted in the default order. For more information, see
	// [Sorting and filtering list
	// results](https://cloud.google.com/kms/docs/sorting-and-filtering).
	OrderBy       string `protobuf:"bytes,5,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListImportJobsRequest) Reset() {
	*x = ListImportJobsRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListImportJobsRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListImportJobsRequest) ProtoMessage() {}

func (x *ListImportJobsRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListImportJobsRequest.ProtoReflect.Descriptor instead.
func (*ListImportJobsRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{3}
}

func (x *ListImportJobsRequest) GetParent() string {
	if x != nil {
		return x.Parent
	}
	return ""
}

func (x *ListImportJobsRequest) GetPageSize() int32 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListImportJobsRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

func (x *ListImportJobsRequest) GetFilter() string {
	if x != nil {
		return x.Filter
	}
	return ""
}

func (x *ListImportJobsRequest) GetOrderBy() string {
	if x != nil {
		return x.OrderBy
	}
	return ""
}

// Request message for
// [KeyManagementService.ListRetiredResources][google.cloud.kms.v1.KeyManagementService.ListRetiredResources].
type ListRetiredResourcesRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The project-specific location holding the
	// [RetiredResources][google.cloud.kms.v1.RetiredResource], in the format
	// `projects/*/locations/*`.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Optional. Optional limit on the number of
	// [RetiredResources][google.cloud.kms.v1.RetiredResource] to be included in
	// the response. Further
	// [RetiredResources][google.cloud.kms.v1.RetiredResource] can subsequently be
	// obtained by including the
	// [ListRetiredResourcesResponse.next_page_token][google.cloud.kms.v1.ListRetiredResourcesResponse.next_page_token]
	// in a subsequent request. If unspecified, the server will pick an
	// appropriate default.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Optional. Optional pagination token, returned earlier via
	// [ListRetiredResourcesResponse.next_page_token][google.cloud.kms.v1.ListRetiredResourcesResponse.next_page_token].
	PageToken     string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListRetiredResourcesRequest) Reset() {
	*x = ListRetiredResourcesRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListRetiredResourcesRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListRetiredResourcesRequest) ProtoMessage() {}

func (x *ListRetiredResourcesRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListRetiredResourcesRequest.ProtoReflect.Descriptor instead.
func (*ListRetiredResourcesRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{4}
}

func (x *ListRetiredResourcesRequest) GetParent() string {
	if x != nil {
		return x.Parent
	}
	return ""
}

func (x *ListRetiredResourcesRequest) GetPageSize() int32 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListRetiredResourcesRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

// Response message for
// [KeyManagementService.ListKeyRings][google.cloud.kms.v1.KeyManagementService.ListKeyRings].
type ListKeyRingsResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The list of [KeyRings][google.cloud.kms.v1.KeyRing].
	KeyRings []*KeyRing `protobuf:"bytes,1,rep,name=key_rings,json=keyRings,proto3" json:"key_rings,omitempty"`
	// A token to retrieve next page of results. Pass this value in
	// [ListKeyRingsRequest.page_token][google.cloud.kms.v1.ListKeyRingsRequest.page_token]
	// to retrieve the next page of results.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// The total number of [KeyRings][google.cloud.kms.v1.KeyRing] that matched
	// the query.
	//
	// This field is not populated if
	// [ListKeyRingsRequest.filter][google.cloud.kms.v1.ListKeyRingsRequest.filter]
	// is applied.
	TotalSize     int32 `protobuf:"varint,3,opt,name=total_size,json=totalSize,proto3" json:"total_size,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListKeyRingsResponse) Reset() {
	*x = ListKeyRingsResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListKeyRingsResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListKeyRingsResponse) ProtoMessage() {}

func (x *ListKeyRingsResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListKeyRingsResponse.ProtoReflect.Descriptor instead.
func (*ListKeyRingsResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{5}
}

func (x *ListKeyRingsResponse) GetKeyRings() []*KeyRing {
	if x != nil {
		return x.KeyRings
	}
	return nil
}

func (x *ListKeyRingsResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

func (x *ListKeyRingsResponse) GetTotalSize() int32 {
	if x != nil {
		return x.TotalSize
	}
	return 0
}

// Response message for
// [KeyManagementService.ListCryptoKeys][google.cloud.kms.v1.KeyManagementService.ListCryptoKeys].
type ListCryptoKeysResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The list of [CryptoKeys][google.cloud.kms.v1.CryptoKey].
	CryptoKeys []*CryptoKey `protobuf:"bytes,1,rep,name=crypto_keys,json=cryptoKeys,proto3" json:"crypto_keys,omitempty"`
	// A token to retrieve next page of results. Pass this value in
	// [ListCryptoKeysRequest.page_token][google.cloud.kms.v1.ListCryptoKeysRequest.page_token]
	// to retrieve the next page of results.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// The total number of [CryptoKeys][google.cloud.kms.v1.CryptoKey] that
	// matched the query.
	//
	// This field is not populated if
	// [ListCryptoKeysRequest.filter][google.cloud.kms.v1.ListCryptoKeysRequest.filter]
	// is applied.
	TotalSize     int32 `protobuf:"varint,3,opt,name=total_size,json=totalSize,proto3" json:"total_size,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListCryptoKeysResponse) Reset() {
	*x = ListCryptoKeysResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[6]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListCryptoKeysResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListCryptoKeysResponse) ProtoMessage() {}

func (x *ListCryptoKeysResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[6]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListCryptoKeysResponse.ProtoReflect.Descriptor instead.
func (*ListCryptoKeysResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{6}
}

func (x *ListCryptoKeysResponse) GetCryptoKeys() []*CryptoKey {
	if x != nil {
		return x.CryptoKeys
	}
	return nil
}

func (x *ListCryptoKeysResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

func (x *ListCryptoKeysResponse) GetTotalSize() int32 {
	if x != nil {
		return x.TotalSize
	}
	return 0
}

// Response message for
// [KeyManagementService.ListCryptoKeyVersions][google.cloud.kms.v1.KeyManagementService.ListCryptoKeyVersions].
type ListCryptoKeyVersionsResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The list of [CryptoKeyVersions][google.cloud.kms.v1.CryptoKeyVersion].
	CryptoKeyVersions []*CryptoKeyVersion `protobuf:"bytes,1,rep,name=crypto_key_versions,json=cryptoKeyVersions,proto3" json:"crypto_key_versions,omitempty"`
	// A token to retrieve next page of results. Pass this value in
	// [ListCryptoKeyVersionsRequest.page_token][google.cloud.kms.v1.ListCryptoKeyVersionsRequest.page_token]
	// to retrieve the next page of results.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// The total number of
	// [CryptoKeyVersions][google.cloud.kms.v1.CryptoKeyVersion] that matched the
	// query.
	//
	// This field is not populated if
	// [ListCryptoKeyVersionsRequest.filter][google.cloud.kms.v1.ListCryptoKeyVersionsRequest.filter]
	// is applied.
	TotalSize     int32 `protobuf:"varint,3,opt,name=total_size,json=totalSize,proto3" json:"total_size,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListCryptoKeyVersionsResponse) Reset() {
	*x = ListCryptoKeyVersionsResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[7]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListCryptoKeyVersionsResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListCryptoKeyVersionsResponse) ProtoMessage() {}

func (x *ListCryptoKeyVersionsResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[7]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListCryptoKeyVersionsResponse.ProtoReflect.Descriptor instead.
func (*ListCryptoKeyVersionsResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{7}
}

func (x *ListCryptoKeyVersionsResponse) GetCryptoKeyVersions() []*CryptoKeyVersion {
	if x != nil {
		return x.CryptoKeyVersions
	}
	return nil
}

func (x *ListCryptoKeyVersionsResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

func (x *ListCryptoKeyVersionsResponse) GetTotalSize() int32 {
	if x != nil {
		return x.TotalSize
	}
	return 0
}

// Response message for
// [KeyManagementService.ListImportJobs][google.cloud.kms.v1.KeyManagementService.ListImportJobs].
type ListImportJobsResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The list of [ImportJobs][google.cloud.kms.v1.ImportJob].
	ImportJobs []*ImportJob `protobuf:"bytes,1,rep,name=import_jobs,json=importJobs,proto3" json:"import_jobs,omitempty"`
	// A token to retrieve next page of results. Pass this value in
	// [ListImportJobsRequest.page_token][google.cloud.kms.v1.ListImportJobsRequest.page_token]
	// to retrieve the next page of results.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// The total number of [ImportJobs][google.cloud.kms.v1.ImportJob] that
	// matched the query.
	//
	// This field is not populated if
	// [ListImportJobsRequest.filter][google.cloud.kms.v1.ListImportJobsRequest.filter]
	// is applied.
	TotalSize     int32 `protobuf:"varint,3,opt,name=total_size,json=totalSize,proto3" json:"total_size,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListImportJobsResponse) Reset() {
	*x = ListImportJobsResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[8]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListImportJobsResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListImportJobsResponse) ProtoMessage() {}

func (x *ListImportJobsResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[8]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListImportJobsResponse.ProtoReflect.Descriptor instead.
func (*ListImportJobsResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{8}
}

func (x *ListImportJobsResponse) GetImportJobs() []*ImportJob {
	if x != nil {
		return x.ImportJobs
	}
	return nil
}

func (x *ListImportJobsResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

func (x *ListImportJobsResponse) GetTotalSize() int32 {
	if x != nil {
		return x.TotalSize
	}
	return 0
}

// Response message for
// [KeyManagementService.ListRetiredResources][google.cloud.kms.v1.KeyManagementService.ListRetiredResources].
type ListRetiredResourcesResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The list of [RetiredResources][google.cloud.kms.v1.RetiredResource].
	RetiredResources []*RetiredResource `protobuf:"bytes,1,rep,name=retired_resources,json=retiredResources,proto3" json:"retired_resources,omitempty"`
	// A token to retrieve the next page of results. Pass this value in
	// [ListRetiredResourcesRequest.page_token][google.cloud.kms.v1.ListRetiredResourcesRequest.page_token]
	// to retrieve the next page of results.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// The total number of [RetiredResources][google.cloud.kms.v1.RetiredResource]
	// that matched the query.
	TotalSize     int64 `protobuf:"varint,3,opt,name=total_size,json=totalSize,proto3" json:"total_size,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListRetiredResourcesResponse) Reset() {
	*x = ListRetiredResourcesResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[9]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListRetiredResourcesResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListRetiredResourcesResponse) ProtoMessage() {}

func (x *ListRetiredResourcesResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[9]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListRetiredResourcesResponse.ProtoReflect.Descriptor instead.
func (*ListRetiredResourcesResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{9}
}

func (x *ListRetiredResourcesResponse) GetRetiredResources() []*RetiredResource {
	if x != nil {
		return x.RetiredResources
	}
	return nil
}

func (x *ListRetiredResourcesResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

func (x *ListRetiredResourcesResponse) GetTotalSize() int64 {
	if x != nil {
		return x.TotalSize
	}
	return 0
}

// Request message for
// [KeyManagementService.GetKeyRing][google.cloud.kms.v1.KeyManagementService.GetKeyRing].
type GetKeyRingRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.KeyRing.name] of the
	// [KeyRing][google.cloud.kms.v1.KeyRing] to get.
	Name          string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetKeyRingRequest) Reset() {
	*x = GetKeyRingRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[10]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetKeyRingRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetKeyRingRequest) ProtoMessage() {}

func (x *GetKeyRingRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[10]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetKeyRingRequest.ProtoReflect.Descriptor instead.
func (*GetKeyRingRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{10}
}

func (x *GetKeyRingRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

// Request message for
// [KeyManagementService.GetCryptoKey][google.cloud.kms.v1.KeyManagementService.GetCryptoKey].
type GetCryptoKeyRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.CryptoKey.name] of the
	// [CryptoKey][google.cloud.kms.v1.CryptoKey] to get.
	Name          string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetCryptoKeyRequest) Reset() {
	*x = GetCryptoKeyRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[11]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetCryptoKeyRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetCryptoKeyRequest) ProtoMessage() {}

func (x *GetCryptoKeyRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[11]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetCryptoKeyRequest.ProtoReflect.Descriptor instead.
func (*GetCryptoKeyRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{11}
}

func (x *GetCryptoKeyRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

// Request message for
// [KeyManagementService.GetCryptoKeyVersion][google.cloud.kms.v1.KeyManagementService.GetCryptoKeyVersion].
type GetCryptoKeyVersionRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.CryptoKeyVersion.name] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to get.
	Name          string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetCryptoKeyVersionRequest) Reset() {
	*x = GetCryptoKeyVersionRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[12]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetCryptoKeyVersionRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetCryptoKeyVersionRequest) ProtoMessage() {}

func (x *GetCryptoKeyVersionRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[12]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetCryptoKeyVersionRequest.ProtoReflect.Descriptor instead.
func (*GetCryptoKeyVersionRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{12}
}

func (x *GetCryptoKeyVersionRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

// Request message for
// [KeyManagementService.GetPublicKey][google.cloud.kms.v1.KeyManagementService.GetPublicKey].
type GetPublicKeyRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.CryptoKeyVersion.name] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] public key to get.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Optional. The [PublicKey][google.cloud.kms.v1.PublicKey] format specified
	// by the user. This field is required for PQC algorithms. If specified, the
	// public key will be exported through the
	// [public_key][google.cloud.kms.v1.PublicKey.public_key] field in the
	// requested format. Otherwise, the [pem][google.cloud.kms.v1.PublicKey.pem]
	// field will be populated for non-PQC algorithms, and an error will be
	// returned for PQC algorithms.
	PublicKeyFormat PublicKey_PublicKeyFormat `protobuf:"varint,2,opt,name=public_key_format,json=publicKeyFormat,proto3,enum=google.cloud.kms.v1.PublicKey_PublicKeyFormat" json:"public_key_format,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *GetPublicKeyRequest) Reset() {
	*x = GetPublicKeyRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[13]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetPublicKeyRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetPublicKeyRequest) ProtoMessage() {}

func (x *GetPublicKeyRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[13]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetPublicKeyRequest.ProtoReflect.Descriptor instead.
func (*GetPublicKeyRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{13}
}

func (x *GetPublicKeyRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *GetPublicKeyRequest) GetPublicKeyFormat() PublicKey_PublicKeyFormat {
	if x != nil {
		return x.PublicKeyFormat
	}
	return PublicKey_PUBLIC_KEY_FORMAT_UNSPECIFIED
}

// Request message for
// [KeyManagementService.GetImportJob][google.cloud.kms.v1.KeyManagementService.GetImportJob].
type GetImportJobRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.ImportJob.name] of the
	// [ImportJob][google.cloud.kms.v1.ImportJob] to get.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Optional. Specifies the [WrappingPublicKey][] format.
	// If not specified:
	//   - For RSA-based import methods, the wrapping key will be returned in PEM
	//     format
	//   - For pure ML-KEM-based import methods, the wrapping key will be returned
	//     in the raw bytes format specified in FIPS-203
	//   - For X-Wing-based import methods, the wrapping key will be returned in
	//     the raw bytes format specified in
	//     https://datatracker.ietf.org/doc/draft-connolly-cfrg-xwing-kem.
	PublicKeyFormat PublicKey_PublicKeyFormat `protobuf:"varint,2,opt,name=public_key_format,json=publicKeyFormat,proto3,enum=google.cloud.kms.v1.PublicKey_PublicKeyFormat" json:"public_key_format,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *GetImportJobRequest) Reset() {
	*x = GetImportJobRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[14]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetImportJobRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetImportJobRequest) ProtoMessage() {}

func (x *GetImportJobRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[14]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetImportJobRequest.ProtoReflect.Descriptor instead.
func (*GetImportJobRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{14}
}

func (x *GetImportJobRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *GetImportJobRequest) GetPublicKeyFormat() PublicKey_PublicKeyFormat {
	if x != nil {
		return x.PublicKeyFormat
	}
	return PublicKey_PUBLIC_KEY_FORMAT_UNSPECIFIED
}

// Request message for
// [KeyManagementService.GetRetiredResource][google.cloud.kms.v1.KeyManagementService.GetRetiredResource].
type GetRetiredResourceRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.RetiredResource.name] of the
	// [RetiredResource][google.cloud.kms.v1.RetiredResource] to get.
	Name          string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetRetiredResourceRequest) Reset() {
	*x = GetRetiredResourceRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[15]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetRetiredResourceRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetRetiredResourceRequest) ProtoMessage() {}

func (x *GetRetiredResourceRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[15]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetRetiredResourceRequest.ProtoReflect.Descriptor instead.
func (*GetRetiredResourceRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{15}
}

func (x *GetRetiredResourceRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

// Request message for
// [KeyManagementService.CreateKeyRing][google.cloud.kms.v1.KeyManagementService.CreateKeyRing].
type CreateKeyRingRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the location associated with the
	// [KeyRings][google.cloud.kms.v1.KeyRing], in the format
	// `projects/*/locations/*`.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. It must be unique within a location and match the regular
	// expression `[a-zA-Z0-9_-]{1,63}`
	KeyRingId string `protobuf:"bytes,2,opt,name=key_ring_id,json=keyRingId,proto3" json:"key_ring_id,omitempty"`
	// Required. A [KeyRing][google.cloud.kms.v1.KeyRing] with initial field
	// values.
	KeyRing       *KeyRing `protobuf:"bytes,3,opt,name=key_ring,json=keyRing,proto3" json:"key_ring,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CreateKeyRingRequest) Reset() {
	*x = CreateKeyRingRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[16]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateKeyRingRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateKeyRingRequest) ProtoMessage() {}

func (x *CreateKeyRingRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[16]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateKeyRingRequest.ProtoReflect.Descriptor instead.
func (*CreateKeyRingRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{16}
}

func (x *CreateKeyRingRequest) GetParent() string {
	if x != nil {
		return x.Parent
	}
	return ""
}

func (x *CreateKeyRingRequest) GetKeyRingId() string {
	if x != nil {
		return x.KeyRingId
	}
	return ""
}

func (x *CreateKeyRingRequest) GetKeyRing() *KeyRing {
	if x != nil {
		return x.KeyRing
	}
	return nil
}

// Request message for
// [KeyManagementService.CreateCryptoKey][google.cloud.kms.v1.KeyManagementService.CreateCryptoKey].
type CreateCryptoKeyRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.KeyRing.name] of the KeyRing
	// associated with the [CryptoKeys][google.cloud.kms.v1.CryptoKey].
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. It must be unique within a KeyRing and match the regular
	// expression `[a-zA-Z0-9_-]{1,63}`
	CryptoKeyId string `protobuf:"bytes,2,opt,name=crypto_key_id,json=cryptoKeyId,proto3" json:"crypto_key_id,omitempty"`
	// Required. A [CryptoKey][google.cloud.kms.v1.CryptoKey] with initial field
	// values.
	CryptoKey *CryptoKey `protobuf:"bytes,3,opt,name=crypto_key,json=cryptoKey,proto3" json:"crypto_key,omitempty"`
	// If set to true, the request will create a
	// [CryptoKey][google.cloud.kms.v1.CryptoKey] without any
	// [CryptoKeyVersions][google.cloud.kms.v1.CryptoKeyVersion]. You must
	// manually call
	// [CreateCryptoKeyVersion][google.cloud.kms.v1.KeyManagementService.CreateCryptoKeyVersion]
	// or
	// [ImportCryptoKeyVersion][google.cloud.kms.v1.KeyManagementService.ImportCryptoKeyVersion]
	// before you can use this [CryptoKey][google.cloud.kms.v1.CryptoKey].
	SkipInitialVersionCreation bool `protobuf:"varint,5,opt,name=skip_initial_version_creation,json=skipInitialVersionCreation,proto3" json:"skip_initial_version_creation,omitempty"`
	unknownFields              protoimpl.UnknownFields
	sizeCache                  protoimpl.SizeCache
}

func (x *CreateCryptoKeyRequest) Reset() {
	*x = CreateCryptoKeyRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[17]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateCryptoKeyRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateCryptoKeyRequest) ProtoMessage() {}

func (x *CreateCryptoKeyRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[17]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateCryptoKeyRequest.ProtoReflect.Descriptor instead.
func (*CreateCryptoKeyRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{17}
}

func (x *CreateCryptoKeyRequest) GetParent() string {
	if x != nil {
		return x.Parent
	}
	return ""
}

func (x *CreateCryptoKeyRequest) GetCryptoKeyId() string {
	if x != nil {
		return x.CryptoKeyId
	}
	return ""
}

func (x *CreateCryptoKeyRequest) GetCryptoKey() *CryptoKey {
	if x != nil {
		return x.CryptoKey
	}
	return nil
}

func (x *CreateCryptoKeyRequest) GetSkipInitialVersionCreation() bool {
	if x != nil {
		return x.SkipInitialVersionCreation
	}
	return false
}

// Request message for
// [KeyManagementService.CreateCryptoKeyVersion][google.cloud.kms.v1.KeyManagementService.CreateCryptoKeyVersion].
type CreateCryptoKeyVersionRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.CryptoKey.name] of the
	// [CryptoKey][google.cloud.kms.v1.CryptoKey] associated with the
	// [CryptoKeyVersions][google.cloud.kms.v1.CryptoKeyVersion].
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. A [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] with
	// initial field values.
	CryptoKeyVersion *CryptoKeyVersion `protobuf:"bytes,2,opt,name=crypto_key_version,json=cryptoKeyVersion,proto3" json:"crypto_key_version,omitempty"`
	unknownFields    protoimpl.UnknownFields
	sizeCache        protoimpl.SizeCache
}

func (x *CreateCryptoKeyVersionRequest) Reset() {
	*x = CreateCryptoKeyVersionRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[18]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateCryptoKeyVersionRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateCryptoKeyVersionRequest) ProtoMessage() {}

func (x *CreateCryptoKeyVersionRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[18]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateCryptoKeyVersionRequest.ProtoReflect.Descriptor instead.
func (*CreateCryptoKeyVersionRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{18}
}

func (x *CreateCryptoKeyVersionRequest) GetParent() string {
	if x != nil {
		return x.Parent
	}
	return ""
}

func (x *CreateCryptoKeyVersionRequest) GetCryptoKeyVersion() *CryptoKeyVersion {
	if x != nil {
		return x.CryptoKeyVersion
	}
	return nil
}

// Request message for
// [KeyManagementService.DeleteCryptoKey][google.cloud.kms.v1.KeyManagementService.DeleteCryptoKey].
type DeleteCryptoKeyRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.CryptoKey.name] of the
	// [CryptoKey][google.cloud.kms.v1.CryptoKey] to delete.
	Name          string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DeleteCryptoKeyRequest) Reset() {
	*x = DeleteCryptoKeyRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[19]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteCryptoKeyRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteCryptoKeyRequest) ProtoMessage() {}

func (x *DeleteCryptoKeyRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[19]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteCryptoKeyRequest.ProtoReflect.Descriptor instead.
func (*DeleteCryptoKeyRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{19}
}

func (x *DeleteCryptoKeyRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

// Request message for
// [KeyManagementService.DeleteCryptoKeyVersion][google.cloud.kms.v1.KeyManagementService.DeleteCryptoKeyVersion].
type DeleteCryptoKeyVersionRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.CryptoKeyVersion.name] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to delete.
	Name          string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DeleteCryptoKeyVersionRequest) Reset() {
	*x = DeleteCryptoKeyVersionRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[20]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteCryptoKeyVersionRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteCryptoKeyVersionRequest) ProtoMessage() {}

func (x *DeleteCryptoKeyVersionRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[20]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteCryptoKeyVersionRequest.ProtoReflect.Descriptor instead.
func (*DeleteCryptoKeyVersionRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{20}
}

func (x *DeleteCryptoKeyVersionRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

// Request message for
// [KeyManagementService.ImportCryptoKeyVersion][google.cloud.kms.v1.KeyManagementService.ImportCryptoKeyVersion].
type ImportCryptoKeyVersionRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.CryptoKey.name] of the
	// [CryptoKey][google.cloud.kms.v1.CryptoKey] to be imported into.
	//
	// The create permission is only required on this key when creating a new
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion].
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Optional. The optional [name][google.cloud.kms.v1.CryptoKeyVersion.name] of
	// an existing [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to
	// target for an import operation. If this field is not present, a new
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] containing the
	// supplied key material is created.
	//
	// If this field is present, the supplied key material is imported into
	// the existing [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion]. To
	// import into an existing
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion], the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] must be a child of
	// [ImportCryptoKeyVersionRequest.parent][google.cloud.kms.v1.ImportCryptoKeyVersionRequest.parent],
	// have been previously created via
	// [ImportCryptoKeyVersion][google.cloud.kms.v1.KeyManagementService.ImportCryptoKeyVersion],
	// and be in
	// [DESTROYED][google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionState.DESTROYED]
	// or
	// [IMPORT_FAILED][google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionState.IMPORT_FAILED]
	// state. The key material and algorithm must match the previous
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] exactly if the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] has ever contained
	// key material.
	CryptoKeyVersion string `protobuf:"bytes,6,opt,name=crypto_key_version,json=cryptoKeyVersion,proto3" json:"crypto_key_version,omitempty"`
	// Required. The
	// [algorithm][google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionAlgorithm]
	// of the key being imported. This does not need to match the
	// [version_template][google.cloud.kms.v1.CryptoKey.version_template] of the
	// [CryptoKey][google.cloud.kms.v1.CryptoKey] this version imports into.
	Algorithm CryptoKeyVersion_CryptoKeyVersionAlgorithm `protobuf:"varint,2,opt,name=algorithm,proto3,enum=google.cloud.kms.v1.CryptoKeyVersion_CryptoKeyVersionAlgorithm" json:"algorithm,omitempty"`
	// Required. The [name][google.cloud.kms.v1.ImportJob.name] of the
	// [ImportJob][google.cloud.kms.v1.ImportJob] that was used to wrap this key
	// material.
	ImportJob string `protobuf:"bytes,4,opt,name=import_job,json=importJob,proto3" json:"import_job,omitempty"`
	// Optional. The wrapped key material to import.
	//
	// Before wrapping, key material must be formatted. If importing symmetric key
	// material, the expected key material format is plain bytes. If importing
	// asymmetric key material, the expected key material format is PKCS#8-encoded
	// DER (the PrivateKeyInfo structure from RFC 5208).
	//
	// When wrapping with import methods
	// ([RSA_OAEP_3072_SHA1_AES_256][google.cloud.kms.v1.ImportJob.ImportMethod.RSA_OAEP_3072_SHA1_AES_256]
	// or
	// [RSA_OAEP_4096_SHA1_AES_256][google.cloud.kms.v1.ImportJob.ImportMethod.RSA_OAEP_4096_SHA1_AES_256]
	// or
	// [RSA_OAEP_3072_SHA256_AES_256][google.cloud.kms.v1.ImportJob.ImportMethod.RSA_OAEP_3072_SHA256_AES_256]
	// or
	// [RSA_OAEP_4096_SHA256_AES_256][google.cloud.kms.v1.ImportJob.ImportMethod.RSA_OAEP_4096_SHA256_AES_256]),
	//
	// this field must contain the concatenation of:
	// <ol>
	//
	//	<li>An ephemeral AES-256 wrapping key wrapped with the
	//	    [public_key][google.cloud.kms.v1.ImportJob.public_key] using
	//	    RSAES-OAEP with SHA-1/SHA-256, MGF1 with SHA-1/SHA-256, and an empty
	//	    label.
	//	</li>
	//	<li>The formatted key to be imported, wrapped with the ephemeral AES-256
	//	    key using AES-KWP (RFC 5649).
	//	</li>
	//
	// </ol>
	//
	// This format is the same as the format produced by PKCS#11 mechanism
	// CKM_RSA_AES_KEY_WRAP.
	//
	// When wrapping with import methods
	// ([RSA_OAEP_3072_SHA256][google.cloud.kms.v1.ImportJob.ImportMethod.RSA_OAEP_3072_SHA256]
	// or
	// [RSA_OAEP_4096_SHA256][google.cloud.kms.v1.ImportJob.ImportMethod.RSA_OAEP_4096_SHA256]),
	//
	// this field must contain the formatted key to be imported, wrapped with the
	// [public_key][google.cloud.kms.v1.ImportJob.public_key] using RSAES-OAEP
	// with SHA-256, MGF1 with SHA-256, and an empty label.
	WrappedKey []byte `protobuf:"bytes,8,opt,name=wrapped_key,json=wrappedKey,proto3" json:"wrapped_key,omitempty"`
	// This field is legacy. Use the field
	// [wrapped_key][google.cloud.kms.v1.ImportCryptoKeyVersionRequest.wrapped_key]
	// instead.
	//
	// Types that are valid to be assigned to WrappedKeyMaterial:
	//
	//	*ImportCryptoKeyVersionRequest_RsaAesWrappedKey
	WrappedKeyMaterial isImportCryptoKeyVersionRequest_WrappedKeyMaterial `protobuf_oneof:"wrapped_key_material"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *ImportCryptoKeyVersionRequest) Reset() {
	*x = ImportCryptoKeyVersionRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[21]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ImportCryptoKeyVersionRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ImportCryptoKeyVersionRequest) ProtoMessage() {}

func (x *ImportCryptoKeyVersionRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[21]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ImportCryptoKeyVersionRequest.ProtoReflect.Descriptor instead.
func (*ImportCryptoKeyVersionRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{21}
}

func (x *ImportCryptoKeyVersionRequest) GetParent() string {
	if x != nil {
		return x.Parent
	}
	return ""
}

func (x *ImportCryptoKeyVersionRequest) GetCryptoKeyVersion() string {
	if x != nil {
		return x.CryptoKeyVersion
	}
	return ""
}

func (x *ImportCryptoKeyVersionRequest) GetAlgorithm() CryptoKeyVersion_CryptoKeyVersionAlgorithm {
	if x != nil {
		return x.Algorithm
	}
	return CryptoKeyVersion_CRYPTO_KEY_VERSION_ALGORITHM_UNSPECIFIED
}

func (x *ImportCryptoKeyVersionRequest) GetImportJob() string {
	if x != nil {
		return x.ImportJob
	}
	return ""
}

func (x *ImportCryptoKeyVersionRequest) GetWrappedKey() []byte {
	if x != nil {
		return x.WrappedKey
	}
	return nil
}

func (x *ImportCryptoKeyVersionRequest) GetWrappedKeyMaterial() isImportCryptoKeyVersionRequest_WrappedKeyMaterial {
	if x != nil {
		return x.WrappedKeyMaterial
	}
	return nil
}

func (x *ImportCryptoKeyVersionRequest) GetRsaAesWrappedKey() []byte {
	if x != nil {
		if x, ok := x.WrappedKeyMaterial.(*ImportCryptoKeyVersionRequest_RsaAesWrappedKey); ok {
			return x.RsaAesWrappedKey
		}
	}
	return nil
}

type isImportCryptoKeyVersionRequest_WrappedKeyMaterial interface {
	isImportCryptoKeyVersionRequest_WrappedKeyMaterial()
}

type ImportCryptoKeyVersionRequest_RsaAesWrappedKey struct {
	// Optional. This field has the same meaning as
	// [wrapped_key][google.cloud.kms.v1.ImportCryptoKeyVersionRequest.wrapped_key].
	// Prefer to use that field in new work. Either that field or this field
	// (but not both) must be specified.
	RsaAesWrappedKey []byte `protobuf:"bytes,5,opt,name=rsa_aes_wrapped_key,json=rsaAesWrappedKey,proto3,oneof"`
}

func (*ImportCryptoKeyVersionRequest_RsaAesWrappedKey) isImportCryptoKeyVersionRequest_WrappedKeyMaterial() {
}

// Request message for
// [KeyManagementService.CreateImportJob][google.cloud.kms.v1.KeyManagementService.CreateImportJob].
type CreateImportJobRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The [name][google.cloud.kms.v1.KeyRing.name] of the
	// [KeyRing][google.cloud.kms.v1.KeyRing] associated with the
	// [ImportJobs][google.cloud.kms.v1.ImportJob].
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. It must be unique within a KeyRing and match the regular
	// expression `[a-zA-Z0-9_-]{1,63}`
	ImportJobId string `protobuf:"bytes,2,opt,name=import_job_id,json=importJobId,proto3" json:"import_job_id,omitempty"`
	// Required. An [ImportJob][google.cloud.kms.v1.ImportJob] with initial field
	// values.
	ImportJob     *ImportJob `protobuf:"bytes,3,opt,name=import_job,json=importJob,proto3" json:"import_job,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CreateImportJobRequest) Reset() {
	*x = CreateImportJobRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[22]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateImportJobRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateImportJobRequest) ProtoMessage() {}

func (x *CreateImportJobRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[22]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateImportJobRequest.ProtoReflect.Descriptor instead.
func (*CreateImportJobRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{22}
}

func (x *CreateImportJobRequest) GetParent() string {
	if x != nil {
		return x.Parent
	}
	return ""
}

func (x *CreateImportJobRequest) GetImportJobId() string {
	if x != nil {
		return x.ImportJobId
	}
	return ""
}

func (x *CreateImportJobRequest) GetImportJob() *ImportJob {
	if x != nil {
		return x.ImportJob
	}
	return nil
}

// Request message for
// [KeyManagementService.UpdateCryptoKey][google.cloud.kms.v1.KeyManagementService.UpdateCryptoKey].
type UpdateCryptoKeyRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. [CryptoKey][google.cloud.kms.v1.CryptoKey] with updated values.
	CryptoKey *CryptoKey `protobuf:"bytes,1,opt,name=crypto_key,json=cryptoKey,proto3" json:"crypto_key,omitempty"`
	// Required. List of fields to be updated in this request.
	UpdateMask    *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *UpdateCryptoKeyRequest) Reset() {
	*x = UpdateCryptoKeyRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[23]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *UpdateCryptoKeyRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UpdateCryptoKeyRequest) ProtoMessage() {}

func (x *UpdateCryptoKeyRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[23]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UpdateCryptoKeyRequest.ProtoReflect.Descriptor instead.
func (*UpdateCryptoKeyRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{23}
}

func (x *UpdateCryptoKeyRequest) GetCryptoKey() *CryptoKey {
	if x != nil {
		return x.CryptoKey
	}
	return nil
}

func (x *UpdateCryptoKeyRequest) GetUpdateMask() *fieldmaskpb.FieldMask {
	if x != nil {
		return x.UpdateMask
	}
	return nil
}

// Request message for
// [KeyManagementService.UpdateCryptoKeyVersion][google.cloud.kms.v1.KeyManagementService.UpdateCryptoKeyVersion].
type UpdateCryptoKeyVersionRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] with
	// updated values.
	CryptoKeyVersion *CryptoKeyVersion `protobuf:"bytes,1,opt,name=crypto_key_version,json=cryptoKeyVersion,proto3" json:"crypto_key_version,omitempty"`
	// Required. List of fields to be updated in this request.
	UpdateMask    *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *UpdateCryptoKeyVersionRequest) Reset() {
	*x = UpdateCryptoKeyVersionRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[24]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *UpdateCryptoKeyVersionRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UpdateCryptoKeyVersionRequest) ProtoMessage() {}

func (x *UpdateCryptoKeyVersionRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[24]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UpdateCryptoKeyVersionRequest.ProtoReflect.Descriptor instead.
func (*UpdateCryptoKeyVersionRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{24}
}

func (x *UpdateCryptoKeyVersionRequest) GetCryptoKeyVersion() *CryptoKeyVersion {
	if x != nil {
		return x.CryptoKeyVersion
	}
	return nil
}

func (x *UpdateCryptoKeyVersionRequest) GetUpdateMask() *fieldmaskpb.FieldMask {
	if x != nil {
		return x.UpdateMask
	}
	return nil
}

// Request message for
// [KeyManagementService.UpdateCryptoKeyPrimaryVersion][google.cloud.kms.v1.KeyManagementService.UpdateCryptoKeyPrimaryVersion].
type UpdateCryptoKeyPrimaryVersionRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKey][google.cloud.kms.v1.CryptoKey] to update.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The id of the child
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to use as primary.
	CryptoKeyVersionId string `protobuf:"bytes,2,opt,name=crypto_key_version_id,json=cryptoKeyVersionId,proto3" json:"crypto_key_version_id,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *UpdateCryptoKeyPrimaryVersionRequest) Reset() {
	*x = UpdateCryptoKeyPrimaryVersionRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[25]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *UpdateCryptoKeyPrimaryVersionRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UpdateCryptoKeyPrimaryVersionRequest) ProtoMessage() {}

func (x *UpdateCryptoKeyPrimaryVersionRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[25]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UpdateCryptoKeyPrimaryVersionRequest.ProtoReflect.Descriptor instead.
func (*UpdateCryptoKeyPrimaryVersionRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{25}
}

func (x *UpdateCryptoKeyPrimaryVersionRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *UpdateCryptoKeyPrimaryVersionRequest) GetCryptoKeyVersionId() string {
	if x != nil {
		return x.CryptoKeyVersionId
	}
	return ""
}

// Request message for
// [KeyManagementService.DestroyCryptoKeyVersion][google.cloud.kms.v1.KeyManagementService.DestroyCryptoKeyVersion].
type DestroyCryptoKeyVersionRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to destroy.
	Name          string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DestroyCryptoKeyVersionRequest) Reset() {
	*x = DestroyCryptoKeyVersionRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[26]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DestroyCryptoKeyVersionRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DestroyCryptoKeyVersionRequest) ProtoMessage() {}

func (x *DestroyCryptoKeyVersionRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[26]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DestroyCryptoKeyVersionRequest.ProtoReflect.Descriptor instead.
func (*DestroyCryptoKeyVersionRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{26}
}

func (x *DestroyCryptoKeyVersionRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

// Request message for
// [KeyManagementService.RestoreCryptoKeyVersion][google.cloud.kms.v1.KeyManagementService.RestoreCryptoKeyVersion].
type RestoreCryptoKeyVersionRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to restore.
	Name          string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RestoreCryptoKeyVersionRequest) Reset() {
	*x = RestoreCryptoKeyVersionRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[27]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RestoreCryptoKeyVersionRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RestoreCryptoKeyVersionRequest) ProtoMessage() {}

func (x *RestoreCryptoKeyVersionRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[27]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RestoreCryptoKeyVersionRequest.ProtoReflect.Descriptor instead.
func (*RestoreCryptoKeyVersionRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{27}
}

func (x *RestoreCryptoKeyVersionRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

// Request message for
// [KeyManagementService.Encrypt][google.cloud.kms.v1.KeyManagementService.Encrypt].
type EncryptRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKey][google.cloud.kms.v1.CryptoKey] or
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to use for
	// encryption.
	//
	// If a [CryptoKey][google.cloud.kms.v1.CryptoKey] is specified, the server
	// will use its [primary version][google.cloud.kms.v1.CryptoKey.primary].
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The data to encrypt. Must be no larger than 64KiB.
	//
	// The maximum size depends on the key version's
	// [protection_level][google.cloud.kms.v1.CryptoKeyVersionTemplate.protection_level].
	// For [SOFTWARE][google.cloud.kms.v1.ProtectionLevel.SOFTWARE],
	// [EXTERNAL][google.cloud.kms.v1.ProtectionLevel.EXTERNAL], and
	// [EXTERNAL_VPC][google.cloud.kms.v1.ProtectionLevel.EXTERNAL_VPC] keys, the
	// plaintext must be no larger than 64KiB. For
	// [HSM][google.cloud.kms.v1.ProtectionLevel.HSM] keys, the combined length of
	// the plaintext and additional_authenticated_data fields must be no larger
	// than 8KiB.
	Plaintext []byte `protobuf:"bytes,2,opt,name=plaintext,proto3" json:"plaintext,omitempty"`
	// Optional. Optional data that, if specified, must also be provided during
	// decryption through
	// [DecryptRequest.additional_authenticated_data][google.cloud.kms.v1.DecryptRequest.additional_authenticated_data].
	//
	// The maximum size depends on the key version's
	// [protection_level][google.cloud.kms.v1.CryptoKeyVersionTemplate.protection_level].
	// For [SOFTWARE][google.cloud.kms.v1.ProtectionLevel.SOFTWARE],
	// [EXTERNAL][google.cloud.kms.v1.ProtectionLevel.EXTERNAL], and
	// [EXTERNAL_VPC][google.cloud.kms.v1.ProtectionLevel.EXTERNAL_VPC] keys the
	// AAD must be no larger than 64KiB. For
	// [HSM][google.cloud.kms.v1.ProtectionLevel.HSM] keys, the combined length of
	// the plaintext and additional_authenticated_data fields must be no larger
	// than 8KiB.
	AdditionalAuthenticatedData []byte `protobuf:"bytes,3,opt,name=additional_authenticated_data,json=additionalAuthenticatedData,proto3" json:"additional_authenticated_data,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [EncryptRequest.plaintext][google.cloud.kms.v1.EncryptRequest.plaintext].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received
	// [EncryptRequest.plaintext][google.cloud.kms.v1.EncryptRequest.plaintext]
	// using this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C([EncryptRequest.plaintext][google.cloud.kms.v1.EncryptRequest.plaintext])
	// is equal to
	// [EncryptRequest.plaintext_crc32c][google.cloud.kms.v1.EncryptRequest.plaintext_crc32c],
	// and if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	PlaintextCrc32C *wrapperspb.Int64Value `protobuf:"bytes,7,opt,name=plaintext_crc32c,json=plaintextCrc32c,proto3" json:"plaintext_crc32c,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [EncryptRequest.additional_authenticated_data][google.cloud.kms.v1.EncryptRequest.additional_authenticated_data].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received
	// [EncryptRequest.additional_authenticated_data][google.cloud.kms.v1.EncryptRequest.additional_authenticated_data]
	// using this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C([EncryptRequest.additional_authenticated_data][google.cloud.kms.v1.EncryptRequest.additional_authenticated_data])
	// is equal to
	// [EncryptRequest.additional_authenticated_data_crc32c][google.cloud.kms.v1.EncryptRequest.additional_authenticated_data_crc32c],
	// and if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	AdditionalAuthenticatedDataCrc32C *wrapperspb.Int64Value `protobuf:"bytes,8,opt,name=additional_authenticated_data_crc32c,json=additionalAuthenticatedDataCrc32c,proto3" json:"additional_authenticated_data_crc32c,omitempty"`
	unknownFields                     protoimpl.UnknownFields
	sizeCache                         protoimpl.SizeCache
}

func (x *EncryptRequest) Reset() {
	*x = EncryptRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[28]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EncryptRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EncryptRequest) ProtoMessage() {}

func (x *EncryptRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[28]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EncryptRequest.ProtoReflect.Descriptor instead.
func (*EncryptRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{28}
}

func (x *EncryptRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *EncryptRequest) GetPlaintext() []byte {
	if x != nil {
		return x.Plaintext
	}
	return nil
}

func (x *EncryptRequest) GetAdditionalAuthenticatedData() []byte {
	if x != nil {
		return x.AdditionalAuthenticatedData
	}
	return nil
}

func (x *EncryptRequest) GetPlaintextCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.PlaintextCrc32C
	}
	return nil
}

func (x *EncryptRequest) GetAdditionalAuthenticatedDataCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.AdditionalAuthenticatedDataCrc32C
	}
	return nil
}

// Request message for
// [KeyManagementService.Decrypt][google.cloud.kms.v1.KeyManagementService.Decrypt].
type DecryptRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKey][google.cloud.kms.v1.CryptoKey] to use for decryption. The
	// server will choose the appropriate version.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The encrypted data originally returned in
	// [EncryptResponse.ciphertext][google.cloud.kms.v1.EncryptResponse.ciphertext].
	Ciphertext []byte `protobuf:"bytes,2,opt,name=ciphertext,proto3" json:"ciphertext,omitempty"`
	// Optional. Optional data that must match the data originally supplied in
	// [EncryptRequest.additional_authenticated_data][google.cloud.kms.v1.EncryptRequest.additional_authenticated_data].
	AdditionalAuthenticatedData []byte `protobuf:"bytes,3,opt,name=additional_authenticated_data,json=additionalAuthenticatedData,proto3" json:"additional_authenticated_data,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [DecryptRequest.ciphertext][google.cloud.kms.v1.DecryptRequest.ciphertext].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received
	// [DecryptRequest.ciphertext][google.cloud.kms.v1.DecryptRequest.ciphertext]
	// using this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C([DecryptRequest.ciphertext][google.cloud.kms.v1.DecryptRequest.ciphertext])
	// is equal to
	// [DecryptRequest.ciphertext_crc32c][google.cloud.kms.v1.DecryptRequest.ciphertext_crc32c],
	// and if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	CiphertextCrc32C *wrapperspb.Int64Value `protobuf:"bytes,5,opt,name=ciphertext_crc32c,json=ciphertextCrc32c,proto3" json:"ciphertext_crc32c,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [DecryptRequest.additional_authenticated_data][google.cloud.kms.v1.DecryptRequest.additional_authenticated_data].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received
	// [DecryptRequest.additional_authenticated_data][google.cloud.kms.v1.DecryptRequest.additional_authenticated_data]
	// using this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C([DecryptRequest.additional_authenticated_data][google.cloud.kms.v1.DecryptRequest.additional_authenticated_data])
	// is equal to
	// [DecryptRequest.additional_authenticated_data_crc32c][google.cloud.kms.v1.DecryptRequest.additional_authenticated_data_crc32c],
	// and if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	AdditionalAuthenticatedDataCrc32C *wrapperspb.Int64Value `protobuf:"bytes,6,opt,name=additional_authenticated_data_crc32c,json=additionalAuthenticatedDataCrc32c,proto3" json:"additional_authenticated_data_crc32c,omitempty"`
	unknownFields                     protoimpl.UnknownFields
	sizeCache                         protoimpl.SizeCache
}

func (x *DecryptRequest) Reset() {
	*x = DecryptRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[29]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DecryptRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DecryptRequest) ProtoMessage() {}

func (x *DecryptRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[29]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DecryptRequest.ProtoReflect.Descriptor instead.
func (*DecryptRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{29}
}

func (x *DecryptRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *DecryptRequest) GetCiphertext() []byte {
	if x != nil {
		return x.Ciphertext
	}
	return nil
}

func (x *DecryptRequest) GetAdditionalAuthenticatedData() []byte {
	if x != nil {
		return x.AdditionalAuthenticatedData
	}
	return nil
}

func (x *DecryptRequest) GetCiphertextCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.CiphertextCrc32C
	}
	return nil
}

func (x *DecryptRequest) GetAdditionalAuthenticatedDataCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.AdditionalAuthenticatedDataCrc32C
	}
	return nil
}

// Request message for
// [KeyManagementService.RawEncrypt][google.cloud.kms.v1.KeyManagementService.RawEncrypt].
type RawEncryptRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to use for
	// encryption.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The data to encrypt. Must be no larger than 64KiB.
	//
	// The maximum size depends on the key version's
	// [protection_level][google.cloud.kms.v1.CryptoKeyVersionTemplate.protection_level].
	// For [SOFTWARE][google.cloud.kms.v1.ProtectionLevel.SOFTWARE] keys, the
	// plaintext must be no larger than 64KiB. For
	// [HSM][google.cloud.kms.v1.ProtectionLevel.HSM] keys, the combined length of
	// the plaintext and additional_authenticated_data fields must be no larger
	// than 8KiB.
	Plaintext []byte `protobuf:"bytes,2,opt,name=plaintext,proto3" json:"plaintext,omitempty"`
	// Optional. Optional data that, if specified, must also be provided during
	// decryption through
	// [RawDecryptRequest.additional_authenticated_data][google.cloud.kms.v1.RawDecryptRequest.additional_authenticated_data].
	//
	// This field may only be used in conjunction with an
	// [algorithm][google.cloud.kms.v1.CryptoKeyVersion.algorithm] that accepts
	// additional authenticated data (for example, AES-GCM).
	//
	// The maximum size depends on the key version's
	// [protection_level][google.cloud.kms.v1.CryptoKeyVersionTemplate.protection_level].
	// For [SOFTWARE][google.cloud.kms.v1.ProtectionLevel.SOFTWARE] keys, the
	// plaintext must be no larger than 64KiB. For
	// [HSM][google.cloud.kms.v1.ProtectionLevel.HSM] keys, the combined length of
	// the plaintext and additional_authenticated_data fields must be no larger
	// than 8KiB.
	AdditionalAuthenticatedData []byte `protobuf:"bytes,3,opt,name=additional_authenticated_data,json=additionalAuthenticatedData,proto3" json:"additional_authenticated_data,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [RawEncryptRequest.plaintext][google.cloud.kms.v1.RawEncryptRequest.plaintext].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received plaintext using this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that CRC32C(plaintext) is equal
	// to plaintext_crc32c, and if so, perform a limited number of retries. A
	// persistent mismatch may indicate an issue in your computation of the CRC32C
	// checksum. Note: This field is defined as int64 for reasons of compatibility
	// across different languages. However, it is a non-negative integer, which
	// will never exceed 2^32-1, and can be safely downconverted to uint32 in
	// languages that support this type.
	PlaintextCrc32C *wrapperspb.Int64Value `protobuf:"bytes,4,opt,name=plaintext_crc32c,json=plaintextCrc32c,proto3" json:"plaintext_crc32c,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [RawEncryptRequest.additional_authenticated_data][google.cloud.kms.v1.RawEncryptRequest.additional_authenticated_data].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received additional_authenticated_data using
	// this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C(additional_authenticated_data) is equal to
	// additional_authenticated_data_crc32c, and if so, perform
	// a limited number of retries. A persistent mismatch may indicate an issue in
	// your computation of the CRC32C checksum.
	// Note: This field is defined as int64 for reasons of compatibility across
	// different languages. However, it is a non-negative integer, which will
	// never exceed 2^32-1, and can be safely downconverted to uint32 in languages
	// that support this type.
	AdditionalAuthenticatedDataCrc32C *wrapperspb.Int64Value `protobuf:"bytes,5,opt,name=additional_authenticated_data_crc32c,json=additionalAuthenticatedDataCrc32c,proto3" json:"additional_authenticated_data_crc32c,omitempty"`
	// Optional. A customer-supplied initialization vector that will be used for
	// encryption. If it is not provided for AES-CBC and AES-CTR, one will be
	// generated. It will be returned in
	// [RawEncryptResponse.initialization_vector][google.cloud.kms.v1.RawEncryptResponse.initialization_vector].
	InitializationVector []byte `protobuf:"bytes,6,opt,name=initialization_vector,json=initializationVector,proto3" json:"initialization_vector,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [RawEncryptRequest.initialization_vector][google.cloud.kms.v1.RawEncryptRequest.initialization_vector].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received initialization_vector using this
	// checksum. [KeyManagementService][google.cloud.kms.v1.KeyManagementService]
	// will report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C(initialization_vector) is equal to
	// initialization_vector_crc32c, and if so, perform
	// a limited number of retries. A persistent mismatch may indicate an issue in
	// your computation of the CRC32C checksum.
	// Note: This field is defined as int64 for reasons of compatibility across
	// different languages. However, it is a non-negative integer, which will
	// never exceed 2^32-1, and can be safely downconverted to uint32 in languages
	// that support this type.
	InitializationVectorCrc32C *wrapperspb.Int64Value `protobuf:"bytes,7,opt,name=initialization_vector_crc32c,json=initializationVectorCrc32c,proto3" json:"initialization_vector_crc32c,omitempty"`
	unknownFields              protoimpl.UnknownFields
	sizeCache                  protoimpl.SizeCache
}

func (x *RawEncryptRequest) Reset() {
	*x = RawEncryptRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[30]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RawEncryptRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RawEncryptRequest) ProtoMessage() {}

func (x *RawEncryptRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[30]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RawEncryptRequest.ProtoReflect.Descriptor instead.
func (*RawEncryptRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{30}
}

func (x *RawEncryptRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *RawEncryptRequest) GetPlaintext() []byte {
	if x != nil {
		return x.Plaintext
	}
	return nil
}

func (x *RawEncryptRequest) GetAdditionalAuthenticatedData() []byte {
	if x != nil {
		return x.AdditionalAuthenticatedData
	}
	return nil
}

func (x *RawEncryptRequest) GetPlaintextCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.PlaintextCrc32C
	}
	return nil
}

func (x *RawEncryptRequest) GetAdditionalAuthenticatedDataCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.AdditionalAuthenticatedDataCrc32C
	}
	return nil
}

func (x *RawEncryptRequest) GetInitializationVector() []byte {
	if x != nil {
		return x.InitializationVector
	}
	return nil
}

func (x *RawEncryptRequest) GetInitializationVectorCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.InitializationVectorCrc32C
	}
	return nil
}

// Request message for
// [KeyManagementService.RawDecrypt][google.cloud.kms.v1.KeyManagementService.RawDecrypt].
type RawDecryptRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to use for
	// decryption.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The encrypted data originally returned in
	// [RawEncryptResponse.ciphertext][google.cloud.kms.v1.RawEncryptResponse.ciphertext].
	Ciphertext []byte `protobuf:"bytes,2,opt,name=ciphertext,proto3" json:"ciphertext,omitempty"`
	// Optional. Optional data that must match the data originally supplied in
	// [RawEncryptRequest.additional_authenticated_data][google.cloud.kms.v1.RawEncryptRequest.additional_authenticated_data].
	AdditionalAuthenticatedData []byte `protobuf:"bytes,3,opt,name=additional_authenticated_data,json=additionalAuthenticatedData,proto3" json:"additional_authenticated_data,omitempty"`
	// Required. The initialization vector (IV) used during encryption, which must
	// match the data originally provided in
	// [RawEncryptResponse.initialization_vector][google.cloud.kms.v1.RawEncryptResponse.initialization_vector].
	InitializationVector []byte `protobuf:"bytes,4,opt,name=initialization_vector,json=initializationVector,proto3" json:"initialization_vector,omitempty"`
	// The length of the authentication tag that is appended to the end of
	// the ciphertext. If unspecified (0), the default value for the key's
	// algorithm will be used (for AES-GCM, the default value is 16).
	TagLength int32 `protobuf:"varint,5,opt,name=tag_length,json=tagLength,proto3" json:"tag_length,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [RawDecryptRequest.ciphertext][google.cloud.kms.v1.RawDecryptRequest.ciphertext].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received ciphertext using this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that CRC32C(ciphertext) is equal
	// to ciphertext_crc32c, and if so, perform a limited number of retries. A
	// persistent mismatch may indicate an issue in your computation of the CRC32C
	// checksum. Note: This field is defined as int64 for reasons of compatibility
	// across different languages. However, it is a non-negative integer, which
	// will never exceed 2^32-1, and can be safely downconverted to uint32 in
	// languages that support this type.
	CiphertextCrc32C *wrapperspb.Int64Value `protobuf:"bytes,6,opt,name=ciphertext_crc32c,json=ciphertextCrc32c,proto3" json:"ciphertext_crc32c,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [RawDecryptRequest.additional_authenticated_data][google.cloud.kms.v1.RawDecryptRequest.additional_authenticated_data].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received additional_authenticated_data using
	// this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C(additional_authenticated_data) is equal to
	// additional_authenticated_data_crc32c, and if so, perform
	// a limited number of retries. A persistent mismatch may indicate an issue in
	// your computation of the CRC32C checksum.
	// Note: This field is defined as int64 for reasons of compatibility across
	// different languages. However, it is a non-negative integer, which will
	// never exceed 2^32-1, and can be safely downconverted to uint32 in languages
	// that support this type.
	AdditionalAuthenticatedDataCrc32C *wrapperspb.Int64Value `protobuf:"bytes,7,opt,name=additional_authenticated_data_crc32c,json=additionalAuthenticatedDataCrc32c,proto3" json:"additional_authenticated_data_crc32c,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [RawDecryptRequest.initialization_vector][google.cloud.kms.v1.RawDecryptRequest.initialization_vector].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received initialization_vector using this
	// checksum. [KeyManagementService][google.cloud.kms.v1.KeyManagementService]
	// will report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C(initialization_vector) is equal to initialization_vector_crc32c, and
	// if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum.
	// Note: This field is defined as int64 for reasons of compatibility across
	// different languages. However, it is a non-negative integer, which will
	// never exceed 2^32-1, and can be safely downconverted to uint32 in languages
	// that support this type.
	InitializationVectorCrc32C *wrapperspb.Int64Value `protobuf:"bytes,8,opt,name=initialization_vector_crc32c,json=initializationVectorCrc32c,proto3" json:"initialization_vector_crc32c,omitempty"`
	unknownFields              protoimpl.UnknownFields
	sizeCache                  protoimpl.SizeCache
}

func (x *RawDecryptRequest) Reset() {
	*x = RawDecryptRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[31]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RawDecryptRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RawDecryptRequest) ProtoMessage() {}

func (x *RawDecryptRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[31]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RawDecryptRequest.ProtoReflect.Descriptor instead.
func (*RawDecryptRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{31}
}

func (x *RawDecryptRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *RawDecryptRequest) GetCiphertext() []byte {
	if x != nil {
		return x.Ciphertext
	}
	return nil
}

func (x *RawDecryptRequest) GetAdditionalAuthenticatedData() []byte {
	if x != nil {
		return x.AdditionalAuthenticatedData
	}
	return nil
}

func (x *RawDecryptRequest) GetInitializationVector() []byte {
	if x != nil {
		return x.InitializationVector
	}
	return nil
}

func (x *RawDecryptRequest) GetTagLength() int32 {
	if x != nil {
		return x.TagLength
	}
	return 0
}

func (x *RawDecryptRequest) GetCiphertextCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.CiphertextCrc32C
	}
	return nil
}

func (x *RawDecryptRequest) GetAdditionalAuthenticatedDataCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.AdditionalAuthenticatedDataCrc32C
	}
	return nil
}

func (x *RawDecryptRequest) GetInitializationVectorCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.InitializationVectorCrc32C
	}
	return nil
}

// Request message for
// [KeyManagementService.AsymmetricSign][google.cloud.kms.v1.KeyManagementService.AsymmetricSign].
type AsymmetricSignRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to use for
	// signing.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Optional. The digest of the data to sign. The digest must be produced with
	// the same digest algorithm as specified by the key version's
	// [algorithm][google.cloud.kms.v1.CryptoKeyVersion.algorithm].
	//
	// This field may not be supplied if
	// [AsymmetricSignRequest.data][google.cloud.kms.v1.AsymmetricSignRequest.data]
	// is supplied.
	Digest *Digest `protobuf:"bytes,3,opt,name=digest,proto3" json:"digest,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [AsymmetricSignRequest.digest][google.cloud.kms.v1.AsymmetricSignRequest.digest].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received
	// [AsymmetricSignRequest.digest][google.cloud.kms.v1.AsymmetricSignRequest.digest]
	// using this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C([AsymmetricSignRequest.digest][google.cloud.kms.v1.AsymmetricSignRequest.digest])
	// is equal to
	// [AsymmetricSignRequest.digest_crc32c][google.cloud.kms.v1.AsymmetricSignRequest.digest_crc32c],
	// and if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	DigestCrc32C *wrapperspb.Int64Value `protobuf:"bytes,4,opt,name=digest_crc32c,json=digestCrc32c,proto3" json:"digest_crc32c,omitempty"`
	// Optional. The data to sign.
	// It can't be supplied if
	// [AsymmetricSignRequest.digest][google.cloud.kms.v1.AsymmetricSignRequest.digest]
	// is supplied.
	Data []byte `protobuf:"bytes,6,opt,name=data,proto3" json:"data,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [AsymmetricSignRequest.data][google.cloud.kms.v1.AsymmetricSignRequest.data].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received
	// [AsymmetricSignRequest.data][google.cloud.kms.v1.AsymmetricSignRequest.data]
	// using this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C([AsymmetricSignRequest.data][google.cloud.kms.v1.AsymmetricSignRequest.data])
	// is equal to
	// [AsymmetricSignRequest.data_crc32c][google.cloud.kms.v1.AsymmetricSignRequest.data_crc32c],
	// and if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	DataCrc32C    *wrapperspb.Int64Value `protobuf:"bytes,7,opt,name=data_crc32c,json=dataCrc32c,proto3" json:"data_crc32c,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *AsymmetricSignRequest) Reset() {
	*x = AsymmetricSignRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[32]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AsymmetricSignRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AsymmetricSignRequest) ProtoMessage() {}

func (x *AsymmetricSignRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[32]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AsymmetricSignRequest.ProtoReflect.Descriptor instead.
func (*AsymmetricSignRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{32}
}

func (x *AsymmetricSignRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *AsymmetricSignRequest) GetDigest() *Digest {
	if x != nil {
		return x.Digest
	}
	return nil
}

func (x *AsymmetricSignRequest) GetDigestCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.DigestCrc32C
	}
	return nil
}

func (x *AsymmetricSignRequest) GetData() []byte {
	if x != nil {
		return x.Data
	}
	return nil
}

func (x *AsymmetricSignRequest) GetDataCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.DataCrc32C
	}
	return nil
}

// Request message for
// [KeyManagementService.AsymmetricDecrypt][google.cloud.kms.v1.KeyManagementService.AsymmetricDecrypt].
type AsymmetricDecryptRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to use for
	// decryption.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The data encrypted with the named
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion]'s public key using
	// OAEP.
	Ciphertext []byte `protobuf:"bytes,3,opt,name=ciphertext,proto3" json:"ciphertext,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [AsymmetricDecryptRequest.ciphertext][google.cloud.kms.v1.AsymmetricDecryptRequest.ciphertext].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received
	// [AsymmetricDecryptRequest.ciphertext][google.cloud.kms.v1.AsymmetricDecryptRequest.ciphertext]
	// using this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C([AsymmetricDecryptRequest.ciphertext][google.cloud.kms.v1.AsymmetricDecryptRequest.ciphertext])
	// is equal to
	// [AsymmetricDecryptRequest.ciphertext_crc32c][google.cloud.kms.v1.AsymmetricDecryptRequest.ciphertext_crc32c],
	// and if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	CiphertextCrc32C *wrapperspb.Int64Value `protobuf:"bytes,4,opt,name=ciphertext_crc32c,json=ciphertextCrc32c,proto3" json:"ciphertext_crc32c,omitempty"`
	unknownFields    protoimpl.UnknownFields
	sizeCache        protoimpl.SizeCache
}

func (x *AsymmetricDecryptRequest) Reset() {
	*x = AsymmetricDecryptRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[33]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AsymmetricDecryptRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AsymmetricDecryptRequest) ProtoMessage() {}

func (x *AsymmetricDecryptRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[33]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AsymmetricDecryptRequest.ProtoReflect.Descriptor instead.
func (*AsymmetricDecryptRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{33}
}

func (x *AsymmetricDecryptRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *AsymmetricDecryptRequest) GetCiphertext() []byte {
	if x != nil {
		return x.Ciphertext
	}
	return nil
}

func (x *AsymmetricDecryptRequest) GetCiphertextCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.CiphertextCrc32C
	}
	return nil
}

// Request message for
// [KeyManagementService.MacSign][google.cloud.kms.v1.KeyManagementService.MacSign].
type MacSignRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to use for
	// signing.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The data to sign. The MAC tag is computed over this data field
	// based on the specific algorithm.
	Data []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [MacSignRequest.data][google.cloud.kms.v1.MacSignRequest.data]. If
	// specified, [KeyManagementService][google.cloud.kms.v1.KeyManagementService]
	// will verify the integrity of the received
	// [MacSignRequest.data][google.cloud.kms.v1.MacSignRequest.data] using this
	// checksum. [KeyManagementService][google.cloud.kms.v1.KeyManagementService]
	// will report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C([MacSignRequest.data][google.cloud.kms.v1.MacSignRequest.data]) is
	// equal to
	// [MacSignRequest.data_crc32c][google.cloud.kms.v1.MacSignRequest.data_crc32c],
	// and if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	DataCrc32C    *wrapperspb.Int64Value `protobuf:"bytes,3,opt,name=data_crc32c,json=dataCrc32c,proto3" json:"data_crc32c,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *MacSignRequest) Reset() {
	*x = MacSignRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[34]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *MacSignRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MacSignRequest) ProtoMessage() {}

func (x *MacSignRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[34]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MacSignRequest.ProtoReflect.Descriptor instead.
func (*MacSignRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{34}
}

func (x *MacSignRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *MacSignRequest) GetData() []byte {
	if x != nil {
		return x.Data
	}
	return nil
}

func (x *MacSignRequest) GetDataCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.DataCrc32C
	}
	return nil
}

// Request message for
// [KeyManagementService.MacVerify][google.cloud.kms.v1.KeyManagementService.MacVerify].
type MacVerifyRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to use for
	// verification.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The data used previously as a
	// [MacSignRequest.data][google.cloud.kms.v1.MacSignRequest.data] to generate
	// the MAC tag.
	Data []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [MacVerifyRequest.data][google.cloud.kms.v1.MacVerifyRequest.data]. If
	// specified, [KeyManagementService][google.cloud.kms.v1.KeyManagementService]
	// will verify the integrity of the received
	// [MacVerifyRequest.data][google.cloud.kms.v1.MacVerifyRequest.data] using
	// this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C([MacVerifyRequest.data][google.cloud.kms.v1.MacVerifyRequest.data])
	// is equal to
	// [MacVerifyRequest.data_crc32c][google.cloud.kms.v1.MacVerifyRequest.data_crc32c],
	// and if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	DataCrc32C *wrapperspb.Int64Value `protobuf:"bytes,3,opt,name=data_crc32c,json=dataCrc32c,proto3" json:"data_crc32c,omitempty"`
	// Required. The signature to verify.
	Mac []byte `protobuf:"bytes,4,opt,name=mac,proto3" json:"mac,omitempty"`
	// Optional. An optional CRC32C checksum of the
	// [MacVerifyRequest.mac][google.cloud.kms.v1.MacVerifyRequest.mac]. If
	// specified, [KeyManagementService][google.cloud.kms.v1.KeyManagementService]
	// will verify the integrity of the received
	// [MacVerifyRequest.mac][google.cloud.kms.v1.MacVerifyRequest.mac] using this
	// checksum. [KeyManagementService][google.cloud.kms.v1.KeyManagementService]
	// will report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C([MacVerifyRequest.mac][google.cloud.kms.v1.MacVerifyRequest.mac]) is
	// equal to
	// [MacVerifyRequest.mac_crc32c][google.cloud.kms.v1.MacVerifyRequest.mac_crc32c],
	// and if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	MacCrc32C     *wrapperspb.Int64Value `protobuf:"bytes,5,opt,name=mac_crc32c,json=macCrc32c,proto3" json:"mac_crc32c,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *MacVerifyRequest) Reset() {
	*x = MacVerifyRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[35]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *MacVerifyRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MacVerifyRequest) ProtoMessage() {}

func (x *MacVerifyRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[35]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MacVerifyRequest.ProtoReflect.Descriptor instead.
func (*MacVerifyRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{35}
}

func (x *MacVerifyRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *MacVerifyRequest) GetData() []byte {
	if x != nil {
		return x.Data
	}
	return nil
}

func (x *MacVerifyRequest) GetDataCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.DataCrc32C
	}
	return nil
}

func (x *MacVerifyRequest) GetMac() []byte {
	if x != nil {
		return x.Mac
	}
	return nil
}

func (x *MacVerifyRequest) GetMacCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.MacCrc32C
	}
	return nil
}

// Request message for
// [KeyManagementService.Decapsulate][google.cloud.kms.v1.KeyManagementService.Decapsulate].
type DecapsulateRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] to use for
	// decapsulation.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The ciphertext produced from encapsulation with the
	// named [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] public
	// key(s).
	Ciphertext []byte `protobuf:"bytes,2,opt,name=ciphertext,proto3" json:"ciphertext,omitempty"`
	// Optional. A CRC32C checksum of the
	// [DecapsulateRequest.ciphertext][google.cloud.kms.v1.DecapsulateRequest.ciphertext].
	// If specified,
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// verify the integrity of the received
	// [DecapsulateRequest.ciphertext][google.cloud.kms.v1.DecapsulateRequest.ciphertext]
	// using this checksum.
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] will
	// report an error if the checksum verification fails. If you receive a
	// checksum error, your client should verify that
	// CRC32C([DecapsulateRequest.ciphertext][google.cloud.kms.v1.DecapsulateRequest.ciphertext])
	// is equal to
	// [DecapsulateRequest.ciphertext_crc32c][google.cloud.kms.v1.DecapsulateRequest.ciphertext_crc32c],
	// and if so, perform a limited number of retries. A persistent mismatch may
	// indicate an issue in your computation of the CRC32C checksum. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	CiphertextCrc32C *wrapperspb.Int64Value `protobuf:"bytes,3,opt,name=ciphertext_crc32c,json=ciphertextCrc32c,proto3" json:"ciphertext_crc32c,omitempty"`
	unknownFields    protoimpl.UnknownFields
	sizeCache        protoimpl.SizeCache
}

func (x *DecapsulateRequest) Reset() {
	*x = DecapsulateRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[36]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DecapsulateRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DecapsulateRequest) ProtoMessage() {}

func (x *DecapsulateRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[36]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DecapsulateRequest.ProtoReflect.Descriptor instead.
func (*DecapsulateRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{36}
}

func (x *DecapsulateRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *DecapsulateRequest) GetCiphertext() []byte {
	if x != nil {
		return x.Ciphertext
	}
	return nil
}

func (x *DecapsulateRequest) GetCiphertextCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.CiphertextCrc32C
	}
	return nil
}

// Request message for
// [KeyManagementService.GenerateRandomBytes][google.cloud.kms.v1.KeyManagementService.GenerateRandomBytes].
type GenerateRandomBytesRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The project-specific location in which to generate random bytes.
	// For example, "projects/my-project/locations/us-central1".
	Location string `protobuf:"bytes,1,opt,name=location,proto3" json:"location,omitempty"`
	// The length in bytes of the amount of randomness to retrieve.  Minimum 8
	// bytes, maximum 1024 bytes.
	LengthBytes int32 `protobuf:"varint,2,opt,name=length_bytes,json=lengthBytes,proto3" json:"length_bytes,omitempty"`
	// The [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] to use when
	// generating the random data. Currently, only
	// [HSM][google.cloud.kms.v1.ProtectionLevel.HSM] protection level is
	// supported.
	ProtectionLevel ProtectionLevel `protobuf:"varint,3,opt,name=protection_level,json=protectionLevel,proto3,enum=google.cloud.kms.v1.ProtectionLevel" json:"protection_level,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *GenerateRandomBytesRequest) Reset() {
	*x = GenerateRandomBytesRequest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[37]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GenerateRandomBytesRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GenerateRandomBytesRequest) ProtoMessage() {}

func (x *GenerateRandomBytesRequest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[37]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GenerateRandomBytesRequest.ProtoReflect.Descriptor instead.
func (*GenerateRandomBytesRequest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{37}
}

func (x *GenerateRandomBytesRequest) GetLocation() string {
	if x != nil {
		return x.Location
	}
	return ""
}

func (x *GenerateRandomBytesRequest) GetLengthBytes() int32 {
	if x != nil {
		return x.LengthBytes
	}
	return 0
}

func (x *GenerateRandomBytesRequest) GetProtectionLevel() ProtectionLevel {
	if x != nil {
		return x.ProtectionLevel
	}
	return ProtectionLevel_PROTECTION_LEVEL_UNSPECIFIED
}

// Response message for
// [KeyManagementService.Encrypt][google.cloud.kms.v1.KeyManagementService.Encrypt].
type EncryptResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used in
	// encryption. Check this field to verify that the intended resource was used
	// for encryption.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The encrypted data.
	Ciphertext []byte `protobuf:"bytes,2,opt,name=ciphertext,proto3" json:"ciphertext,omitempty"`
	// Integrity verification field. A CRC32C checksum of the returned
	// [EncryptResponse.ciphertext][google.cloud.kms.v1.EncryptResponse.ciphertext].
	// An integrity check of
	// [EncryptResponse.ciphertext][google.cloud.kms.v1.EncryptResponse.ciphertext]
	// can be performed by computing the CRC32C checksum of
	// [EncryptResponse.ciphertext][google.cloud.kms.v1.EncryptResponse.ciphertext]
	// and comparing your results to this field. Discard the response in case of
	// non-matching checksum values, and perform a limited number of retries. A
	// persistent mismatch may indicate an issue in your computation of the CRC32C
	// checksum. Note: This field is defined as int64 for reasons of compatibility
	// across different languages. However, it is a non-negative integer, which
	// will never exceed 2^32-1, and can be safely downconverted to uint32 in
	// languages that support this type.
	CiphertextCrc32C *wrapperspb.Int64Value `protobuf:"bytes,4,opt,name=ciphertext_crc32c,json=ciphertextCrc32c,proto3" json:"ciphertext_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [EncryptRequest.plaintext_crc32c][google.cloud.kms.v1.EncryptRequest.plaintext_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of the
	// [plaintext][google.cloud.kms.v1.EncryptRequest.plaintext]. A false value of
	// this field indicates either that
	// [EncryptRequest.plaintext_crc32c][google.cloud.kms.v1.EncryptRequest.plaintext_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [EncryptRequest.plaintext_crc32c][google.cloud.kms.v1.EncryptRequest.plaintext_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedPlaintextCrc32C bool `protobuf:"varint,5,opt,name=verified_plaintext_crc32c,json=verifiedPlaintextCrc32c,proto3" json:"verified_plaintext_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [EncryptRequest.additional_authenticated_data_crc32c][google.cloud.kms.v1.EncryptRequest.additional_authenticated_data_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of the
	// [AAD][google.cloud.kms.v1.EncryptRequest.additional_authenticated_data]. A
	// false value of this field indicates either that
	// [EncryptRequest.additional_authenticated_data_crc32c][google.cloud.kms.v1.EncryptRequest.additional_authenticated_data_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [EncryptRequest.additional_authenticated_data_crc32c][google.cloud.kms.v1.EncryptRequest.additional_authenticated_data_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedAdditionalAuthenticatedDataCrc32C bool `protobuf:"varint,6,opt,name=verified_additional_authenticated_data_crc32c,json=verifiedAdditionalAuthenticatedDataCrc32c,proto3" json:"verified_additional_authenticated_data_crc32c,omitempty"`
	// The [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used in
	// encryption.
	ProtectionLevel ProtectionLevel `protobuf:"varint,7,opt,name=protection_level,json=protectionLevel,proto3,enum=google.cloud.kms.v1.ProtectionLevel" json:"protection_level,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *EncryptResponse) Reset() {
	*x = EncryptResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[38]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EncryptResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EncryptResponse) ProtoMessage() {}

func (x *EncryptResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[38]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EncryptResponse.ProtoReflect.Descriptor instead.
func (*EncryptResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{38}
}

func (x *EncryptResponse) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *EncryptResponse) GetCiphertext() []byte {
	if x != nil {
		return x.Ciphertext
	}
	return nil
}

func (x *EncryptResponse) GetCiphertextCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.CiphertextCrc32C
	}
	return nil
}

func (x *EncryptResponse) GetVerifiedPlaintextCrc32C() bool {
	if x != nil {
		return x.VerifiedPlaintextCrc32C
	}
	return false
}

func (x *EncryptResponse) GetVerifiedAdditionalAuthenticatedDataCrc32C() bool {
	if x != nil {
		return x.VerifiedAdditionalAuthenticatedDataCrc32C
	}
	return false
}

func (x *EncryptResponse) GetProtectionLevel() ProtectionLevel {
	if x != nil {
		return x.ProtectionLevel
	}
	return ProtectionLevel_PROTECTION_LEVEL_UNSPECIFIED
}

// Response message for
// [KeyManagementService.Decrypt][google.cloud.kms.v1.KeyManagementService.Decrypt].
type DecryptResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The decrypted data originally supplied in
	// [EncryptRequest.plaintext][google.cloud.kms.v1.EncryptRequest.plaintext].
	Plaintext []byte `protobuf:"bytes,1,opt,name=plaintext,proto3" json:"plaintext,omitempty"`
	// Integrity verification field. A CRC32C checksum of the returned
	// [DecryptResponse.plaintext][google.cloud.kms.v1.DecryptResponse.plaintext].
	// An integrity check of
	// [DecryptResponse.plaintext][google.cloud.kms.v1.DecryptResponse.plaintext]
	// can be performed by computing the CRC32C checksum of
	// [DecryptResponse.plaintext][google.cloud.kms.v1.DecryptResponse.plaintext]
	// and comparing your results to this field. Discard the response in case of
	// non-matching checksum values, and perform a limited number of retries. A
	// persistent mismatch may indicate an issue in your computation of the CRC32C
	// checksum. Note: receiving this response message indicates that
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] is able to
	// successfully decrypt the
	// [ciphertext][google.cloud.kms.v1.DecryptRequest.ciphertext]. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	PlaintextCrc32C *wrapperspb.Int64Value `protobuf:"bytes,2,opt,name=plaintext_crc32c,json=plaintextCrc32c,proto3" json:"plaintext_crc32c,omitempty"`
	// Whether the Decryption was performed using the primary key version.
	UsedPrimary bool `protobuf:"varint,3,opt,name=used_primary,json=usedPrimary,proto3" json:"used_primary,omitempty"`
	// The [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used in
	// decryption.
	ProtectionLevel ProtectionLevel `protobuf:"varint,4,opt,name=protection_level,json=protectionLevel,proto3,enum=google.cloud.kms.v1.ProtectionLevel" json:"protection_level,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *DecryptResponse) Reset() {
	*x = DecryptResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[39]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DecryptResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DecryptResponse) ProtoMessage() {}

func (x *DecryptResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[39]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DecryptResponse.ProtoReflect.Descriptor instead.
func (*DecryptResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{39}
}

func (x *DecryptResponse) GetPlaintext() []byte {
	if x != nil {
		return x.Plaintext
	}
	return nil
}

func (x *DecryptResponse) GetPlaintextCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.PlaintextCrc32C
	}
	return nil
}

func (x *DecryptResponse) GetUsedPrimary() bool {
	if x != nil {
		return x.UsedPrimary
	}
	return false
}

func (x *DecryptResponse) GetProtectionLevel() ProtectionLevel {
	if x != nil {
		return x.ProtectionLevel
	}
	return ProtectionLevel_PROTECTION_LEVEL_UNSPECIFIED
}

// Response message for
// [KeyManagementService.RawEncrypt][google.cloud.kms.v1.KeyManagementService.RawEncrypt].
type RawEncryptResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The encrypted data. In the case of AES-GCM, the authentication tag
	// is the [tag_length][google.cloud.kms.v1.RawEncryptResponse.tag_length]
	// bytes at the end of this field.
	Ciphertext []byte `protobuf:"bytes,1,opt,name=ciphertext,proto3" json:"ciphertext,omitempty"`
	// The initialization vector (IV) generated by the service during
	// encryption. This value must be stored and provided in
	// [RawDecryptRequest.initialization_vector][google.cloud.kms.v1.RawDecryptRequest.initialization_vector]
	// at decryption time.
	InitializationVector []byte `protobuf:"bytes,2,opt,name=initialization_vector,json=initializationVector,proto3" json:"initialization_vector,omitempty"`
	// The length of the authentication tag that is appended to
	// the end of the ciphertext.
	TagLength int32 `protobuf:"varint,3,opt,name=tag_length,json=tagLength,proto3" json:"tag_length,omitempty"`
	// Integrity verification field. A CRC32C checksum of the returned
	// [RawEncryptResponse.ciphertext][google.cloud.kms.v1.RawEncryptResponse.ciphertext].
	// An integrity check of ciphertext can be performed by computing the CRC32C
	// checksum of ciphertext and comparing your results to this field. Discard
	// the response in case of non-matching checksum values, and perform a limited
	// number of retries. A persistent mismatch may indicate an issue in your
	// computation of the CRC32C checksum. Note: This field is defined as int64
	// for reasons of compatibility across different languages. However, it is a
	// non-negative integer, which will never exceed 2^32-1, and can be safely
	// downconverted to uint32 in languages that support this type.
	CiphertextCrc32C *wrapperspb.Int64Value `protobuf:"bytes,4,opt,name=ciphertext_crc32c,json=ciphertextCrc32c,proto3" json:"ciphertext_crc32c,omitempty"`
	// Integrity verification field. A CRC32C checksum of the returned
	// [RawEncryptResponse.initialization_vector][google.cloud.kms.v1.RawEncryptResponse.initialization_vector].
	// An integrity check of initialization_vector can be performed by computing
	// the CRC32C checksum of initialization_vector and comparing your results to
	// this field. Discard the response in case of non-matching checksum values,
	// and perform a limited number of retries. A persistent mismatch may indicate
	// an issue in your computation of the CRC32C checksum. Note: This field is
	// defined as int64 for reasons of compatibility across different languages.
	// However, it is a non-negative integer, which will never exceed 2^32-1, and
	// can be safely downconverted to uint32 in languages that support this type.
	InitializationVectorCrc32C *wrapperspb.Int64Value `protobuf:"bytes,5,opt,name=initialization_vector_crc32c,json=initializationVectorCrc32c,proto3" json:"initialization_vector_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [RawEncryptRequest.plaintext_crc32c][google.cloud.kms.v1.RawEncryptRequest.plaintext_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of the plaintext. A false value of this
	// field indicates either that
	// [RawEncryptRequest.plaintext_crc32c][google.cloud.kms.v1.RawEncryptRequest.plaintext_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [RawEncryptRequest.plaintext_crc32c][google.cloud.kms.v1.RawEncryptRequest.plaintext_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedPlaintextCrc32C bool `protobuf:"varint,6,opt,name=verified_plaintext_crc32c,json=verifiedPlaintextCrc32c,proto3" json:"verified_plaintext_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [RawEncryptRequest.additional_authenticated_data_crc32c][google.cloud.kms.v1.RawEncryptRequest.additional_authenticated_data_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of additional_authenticated_data. A false
	// value of this field indicates either that //
	// [RawEncryptRequest.additional_authenticated_data_crc32c][google.cloud.kms.v1.RawEncryptRequest.additional_authenticated_data_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [RawEncryptRequest.additional_authenticated_data_crc32c][google.cloud.kms.v1.RawEncryptRequest.additional_authenticated_data_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedAdditionalAuthenticatedDataCrc32C bool `protobuf:"varint,7,opt,name=verified_additional_authenticated_data_crc32c,json=verifiedAdditionalAuthenticatedDataCrc32c,proto3" json:"verified_additional_authenticated_data_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [RawEncryptRequest.initialization_vector_crc32c][google.cloud.kms.v1.RawEncryptRequest.initialization_vector_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of initialization_vector. A false value of
	// this field indicates either that
	// [RawEncryptRequest.initialization_vector_crc32c][google.cloud.kms.v1.RawEncryptRequest.initialization_vector_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [RawEncryptRequest.initialization_vector_crc32c][google.cloud.kms.v1.RawEncryptRequest.initialization_vector_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedInitializationVectorCrc32C bool `protobuf:"varint,10,opt,name=verified_initialization_vector_crc32c,json=verifiedInitializationVectorCrc32c,proto3" json:"verified_initialization_vector_crc32c,omitempty"`
	// The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used in
	// encryption. Check this field to verify that the intended resource was used
	// for encryption.
	Name string `protobuf:"bytes,8,opt,name=name,proto3" json:"name,omitempty"`
	// The [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used in
	// encryption.
	ProtectionLevel ProtectionLevel `protobuf:"varint,9,opt,name=protection_level,json=protectionLevel,proto3,enum=google.cloud.kms.v1.ProtectionLevel" json:"protection_level,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *RawEncryptResponse) Reset() {
	*x = RawEncryptResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[40]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RawEncryptResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RawEncryptResponse) ProtoMessage() {}

func (x *RawEncryptResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[40]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RawEncryptResponse.ProtoReflect.Descriptor instead.
func (*RawEncryptResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{40}
}

func (x *RawEncryptResponse) GetCiphertext() []byte {
	if x != nil {
		return x.Ciphertext
	}
	return nil
}

func (x *RawEncryptResponse) GetInitializationVector() []byte {
	if x != nil {
		return x.InitializationVector
	}
	return nil
}

func (x *RawEncryptResponse) GetTagLength() int32 {
	if x != nil {
		return x.TagLength
	}
	return 0
}

func (x *RawEncryptResponse) GetCiphertextCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.CiphertextCrc32C
	}
	return nil
}

func (x *RawEncryptResponse) GetInitializationVectorCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.InitializationVectorCrc32C
	}
	return nil
}

func (x *RawEncryptResponse) GetVerifiedPlaintextCrc32C() bool {
	if x != nil {
		return x.VerifiedPlaintextCrc32C
	}
	return false
}

func (x *RawEncryptResponse) GetVerifiedAdditionalAuthenticatedDataCrc32C() bool {
	if x != nil {
		return x.VerifiedAdditionalAuthenticatedDataCrc32C
	}
	return false
}

func (x *RawEncryptResponse) GetVerifiedInitializationVectorCrc32C() bool {
	if x != nil {
		return x.VerifiedInitializationVectorCrc32C
	}
	return false
}

func (x *RawEncryptResponse) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *RawEncryptResponse) GetProtectionLevel() ProtectionLevel {
	if x != nil {
		return x.ProtectionLevel
	}
	return ProtectionLevel_PROTECTION_LEVEL_UNSPECIFIED
}

// Response message for
// [KeyManagementService.RawDecrypt][google.cloud.kms.v1.KeyManagementService.RawDecrypt].
type RawDecryptResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The decrypted data.
	Plaintext []byte `protobuf:"bytes,1,opt,name=plaintext,proto3" json:"plaintext,omitempty"`
	// Integrity verification field. A CRC32C checksum of the returned
	// [RawDecryptResponse.plaintext][google.cloud.kms.v1.RawDecryptResponse.plaintext].
	// An integrity check of plaintext can be performed by computing the CRC32C
	// checksum of plaintext and comparing your results to this field. Discard the
	// response in case of non-matching checksum values, and perform a limited
	// number of retries. A persistent mismatch may indicate an issue in your
	// computation of the CRC32C checksum. Note: receiving this response message
	// indicates that
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] is able to
	// successfully decrypt the
	// [ciphertext][google.cloud.kms.v1.RawDecryptRequest.ciphertext].
	// Note: This field is defined as int64 for reasons of compatibility across
	// different languages. However, it is a non-negative integer, which will
	// never exceed 2^32-1, and can be safely downconverted to uint32 in languages
	// that support this type.
	PlaintextCrc32C *wrapperspb.Int64Value `protobuf:"bytes,2,opt,name=plaintext_crc32c,json=plaintextCrc32c,proto3" json:"plaintext_crc32c,omitempty"`
	// The [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used in
	// decryption.
	ProtectionLevel ProtectionLevel `protobuf:"varint,3,opt,name=protection_level,json=protectionLevel,proto3,enum=google.cloud.kms.v1.ProtectionLevel" json:"protection_level,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [RawDecryptRequest.ciphertext_crc32c][google.cloud.kms.v1.RawDecryptRequest.ciphertext_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of the ciphertext. A false value of this
	// field indicates either that
	// [RawDecryptRequest.ciphertext_crc32c][google.cloud.kms.v1.RawDecryptRequest.ciphertext_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [RawDecryptRequest.ciphertext_crc32c][google.cloud.kms.v1.RawDecryptRequest.ciphertext_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedCiphertextCrc32C bool `protobuf:"varint,4,opt,name=verified_ciphertext_crc32c,json=verifiedCiphertextCrc32c,proto3" json:"verified_ciphertext_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [RawDecryptRequest.additional_authenticated_data_crc32c][google.cloud.kms.v1.RawDecryptRequest.additional_authenticated_data_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of additional_authenticated_data. A false
	// value of this field indicates either that //
	// [RawDecryptRequest.additional_authenticated_data_crc32c][google.cloud.kms.v1.RawDecryptRequest.additional_authenticated_data_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [RawDecryptRequest.additional_authenticated_data_crc32c][google.cloud.kms.v1.RawDecryptRequest.additional_authenticated_data_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedAdditionalAuthenticatedDataCrc32C bool `protobuf:"varint,5,opt,name=verified_additional_authenticated_data_crc32c,json=verifiedAdditionalAuthenticatedDataCrc32c,proto3" json:"verified_additional_authenticated_data_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [RawDecryptRequest.initialization_vector_crc32c][google.cloud.kms.v1.RawDecryptRequest.initialization_vector_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of initialization_vector. A false value of
	// this field indicates either that
	// [RawDecryptRequest.initialization_vector_crc32c][google.cloud.kms.v1.RawDecryptRequest.initialization_vector_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [RawDecryptRequest.initialization_vector_crc32c][google.cloud.kms.v1.RawDecryptRequest.initialization_vector_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedInitializationVectorCrc32C bool `protobuf:"varint,6,opt,name=verified_initialization_vector_crc32c,json=verifiedInitializationVectorCrc32c,proto3" json:"verified_initialization_vector_crc32c,omitempty"`
	unknownFields                      protoimpl.UnknownFields
	sizeCache                          protoimpl.SizeCache
}

func (x *RawDecryptResponse) Reset() {
	*x = RawDecryptResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[41]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RawDecryptResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RawDecryptResponse) ProtoMessage() {}

func (x *RawDecryptResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[41]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RawDecryptResponse.ProtoReflect.Descriptor instead.
func (*RawDecryptResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{41}
}

func (x *RawDecryptResponse) GetPlaintext() []byte {
	if x != nil {
		return x.Plaintext
	}
	return nil
}

func (x *RawDecryptResponse) GetPlaintextCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.PlaintextCrc32C
	}
	return nil
}

func (x *RawDecryptResponse) GetProtectionLevel() ProtectionLevel {
	if x != nil {
		return x.ProtectionLevel
	}
	return ProtectionLevel_PROTECTION_LEVEL_UNSPECIFIED
}

func (x *RawDecryptResponse) GetVerifiedCiphertextCrc32C() bool {
	if x != nil {
		return x.VerifiedCiphertextCrc32C
	}
	return false
}

func (x *RawDecryptResponse) GetVerifiedAdditionalAuthenticatedDataCrc32C() bool {
	if x != nil {
		return x.VerifiedAdditionalAuthenticatedDataCrc32C
	}
	return false
}

func (x *RawDecryptResponse) GetVerifiedInitializationVectorCrc32C() bool {
	if x != nil {
		return x.VerifiedInitializationVectorCrc32C
	}
	return false
}

// Response message for
// [KeyManagementService.AsymmetricSign][google.cloud.kms.v1.KeyManagementService.AsymmetricSign].
type AsymmetricSignResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The created signature.
	Signature []byte `protobuf:"bytes,1,opt,name=signature,proto3" json:"signature,omitempty"`
	// Integrity verification field. A CRC32C checksum of the returned
	// [AsymmetricSignResponse.signature][google.cloud.kms.v1.AsymmetricSignResponse.signature].
	// An integrity check of
	// [AsymmetricSignResponse.signature][google.cloud.kms.v1.AsymmetricSignResponse.signature]
	// can be performed by computing the CRC32C checksum of
	// [AsymmetricSignResponse.signature][google.cloud.kms.v1.AsymmetricSignResponse.signature]
	// and comparing your results to this field. Discard the response in case of
	// non-matching checksum values, and perform a limited number of retries. A
	// persistent mismatch may indicate an issue in your computation of the CRC32C
	// checksum. Note: This field is defined as int64 for reasons of compatibility
	// across different languages. However, it is a non-negative integer, which
	// will never exceed 2^32-1, and can be safely downconverted to uint32 in
	// languages that support this type.
	SignatureCrc32C *wrapperspb.Int64Value `protobuf:"bytes,2,opt,name=signature_crc32c,json=signatureCrc32c,proto3" json:"signature_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [AsymmetricSignRequest.digest_crc32c][google.cloud.kms.v1.AsymmetricSignRequest.digest_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of the
	// [digest][google.cloud.kms.v1.AsymmetricSignRequest.digest]. A false value
	// of this field indicates either that
	// [AsymmetricSignRequest.digest_crc32c][google.cloud.kms.v1.AsymmetricSignRequest.digest_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [AsymmetricSignRequest.digest_crc32c][google.cloud.kms.v1.AsymmetricSignRequest.digest_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedDigestCrc32C bool `protobuf:"varint,3,opt,name=verified_digest_crc32c,json=verifiedDigestCrc32c,proto3" json:"verified_digest_crc32c,omitempty"`
	// The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used for signing.
	// Check this field to verify that the intended resource was used for signing.
	Name string `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [AsymmetricSignRequest.data_crc32c][google.cloud.kms.v1.AsymmetricSignRequest.data_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of the
	// [data][google.cloud.kms.v1.AsymmetricSignRequest.data]. A false value of
	// this field indicates either that
	// [AsymmetricSignRequest.data_crc32c][google.cloud.kms.v1.AsymmetricSignRequest.data_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [AsymmetricSignRequest.data_crc32c][google.cloud.kms.v1.AsymmetricSignRequest.data_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedDataCrc32C bool `protobuf:"varint,5,opt,name=verified_data_crc32c,json=verifiedDataCrc32c,proto3" json:"verified_data_crc32c,omitempty"`
	// The [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used for signing.
	ProtectionLevel ProtectionLevel `protobuf:"varint,6,opt,name=protection_level,json=protectionLevel,proto3,enum=google.cloud.kms.v1.ProtectionLevel" json:"protection_level,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *AsymmetricSignResponse) Reset() {
	*x = AsymmetricSignResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[42]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AsymmetricSignResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AsymmetricSignResponse) ProtoMessage() {}

func (x *AsymmetricSignResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[42]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AsymmetricSignResponse.ProtoReflect.Descriptor instead.
func (*AsymmetricSignResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{42}
}

func (x *AsymmetricSignResponse) GetSignature() []byte {
	if x != nil {
		return x.Signature
	}
	return nil
}

func (x *AsymmetricSignResponse) GetSignatureCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.SignatureCrc32C
	}
	return nil
}

func (x *AsymmetricSignResponse) GetVerifiedDigestCrc32C() bool {
	if x != nil {
		return x.VerifiedDigestCrc32C
	}
	return false
}

func (x *AsymmetricSignResponse) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *AsymmetricSignResponse) GetVerifiedDataCrc32C() bool {
	if x != nil {
		return x.VerifiedDataCrc32C
	}
	return false
}

func (x *AsymmetricSignResponse) GetProtectionLevel() ProtectionLevel {
	if x != nil {
		return x.ProtectionLevel
	}
	return ProtectionLevel_PROTECTION_LEVEL_UNSPECIFIED
}

// Response message for
// [KeyManagementService.AsymmetricDecrypt][google.cloud.kms.v1.KeyManagementService.AsymmetricDecrypt].
type AsymmetricDecryptResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The decrypted data originally encrypted with the matching public key.
	Plaintext []byte `protobuf:"bytes,1,opt,name=plaintext,proto3" json:"plaintext,omitempty"`
	// Integrity verification field. A CRC32C checksum of the returned
	// [AsymmetricDecryptResponse.plaintext][google.cloud.kms.v1.AsymmetricDecryptResponse.plaintext].
	// An integrity check of
	// [AsymmetricDecryptResponse.plaintext][google.cloud.kms.v1.AsymmetricDecryptResponse.plaintext]
	// can be performed by computing the CRC32C checksum of
	// [AsymmetricDecryptResponse.plaintext][google.cloud.kms.v1.AsymmetricDecryptResponse.plaintext]
	// and comparing your results to this field. Discard the response in case of
	// non-matching checksum values, and perform a limited number of retries. A
	// persistent mismatch may indicate an issue in your computation of the CRC32C
	// checksum. Note: This field is defined as int64 for reasons of compatibility
	// across different languages. However, it is a non-negative integer, which
	// will never exceed 2^32-1, and can be safely downconverted to uint32 in
	// languages that support this type.
	PlaintextCrc32C *wrapperspb.Int64Value `protobuf:"bytes,2,opt,name=plaintext_crc32c,json=plaintextCrc32c,proto3" json:"plaintext_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [AsymmetricDecryptRequest.ciphertext_crc32c][google.cloud.kms.v1.AsymmetricDecryptRequest.ciphertext_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of the
	// [ciphertext][google.cloud.kms.v1.AsymmetricDecryptRequest.ciphertext]. A
	// false value of this field indicates either that
	// [AsymmetricDecryptRequest.ciphertext_crc32c][google.cloud.kms.v1.AsymmetricDecryptRequest.ciphertext_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [AsymmetricDecryptRequest.ciphertext_crc32c][google.cloud.kms.v1.AsymmetricDecryptRequest.ciphertext_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedCiphertextCrc32C bool `protobuf:"varint,3,opt,name=verified_ciphertext_crc32c,json=verifiedCiphertextCrc32c,proto3" json:"verified_ciphertext_crc32c,omitempty"`
	// The [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used in
	// decryption.
	ProtectionLevel ProtectionLevel `protobuf:"varint,4,opt,name=protection_level,json=protectionLevel,proto3,enum=google.cloud.kms.v1.ProtectionLevel" json:"protection_level,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *AsymmetricDecryptResponse) Reset() {
	*x = AsymmetricDecryptResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[43]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AsymmetricDecryptResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AsymmetricDecryptResponse) ProtoMessage() {}

func (x *AsymmetricDecryptResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[43]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AsymmetricDecryptResponse.ProtoReflect.Descriptor instead.
func (*AsymmetricDecryptResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{43}
}

func (x *AsymmetricDecryptResponse) GetPlaintext() []byte {
	if x != nil {
		return x.Plaintext
	}
	return nil
}

func (x *AsymmetricDecryptResponse) GetPlaintextCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.PlaintextCrc32C
	}
	return nil
}

func (x *AsymmetricDecryptResponse) GetVerifiedCiphertextCrc32C() bool {
	if x != nil {
		return x.VerifiedCiphertextCrc32C
	}
	return false
}

func (x *AsymmetricDecryptResponse) GetProtectionLevel() ProtectionLevel {
	if x != nil {
		return x.ProtectionLevel
	}
	return ProtectionLevel_PROTECTION_LEVEL_UNSPECIFIED
}

// Response message for
// [KeyManagementService.MacSign][google.cloud.kms.v1.KeyManagementService.MacSign].
type MacSignResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used for signing.
	// Check this field to verify that the intended resource was used for signing.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The created signature.
	Mac []byte `protobuf:"bytes,2,opt,name=mac,proto3" json:"mac,omitempty"`
	// Integrity verification field. A CRC32C checksum of the returned
	// [MacSignResponse.mac][google.cloud.kms.v1.MacSignResponse.mac]. An
	// integrity check of
	// [MacSignResponse.mac][google.cloud.kms.v1.MacSignResponse.mac] can be
	// performed by computing the CRC32C checksum of
	// [MacSignResponse.mac][google.cloud.kms.v1.MacSignResponse.mac] and
	// comparing your results to this field. Discard the response in case of
	// non-matching checksum values, and perform a limited number of retries. A
	// persistent mismatch may indicate an issue in your computation of the CRC32C
	// checksum. Note: This field is defined as int64 for reasons of compatibility
	// across different languages. However, it is a non-negative integer, which
	// will never exceed 2^32-1, and can be safely downconverted to uint32 in
	// languages that support this type.
	MacCrc32C *wrapperspb.Int64Value `protobuf:"bytes,3,opt,name=mac_crc32c,json=macCrc32c,proto3" json:"mac_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [MacSignRequest.data_crc32c][google.cloud.kms.v1.MacSignRequest.data_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of the
	// [data][google.cloud.kms.v1.MacSignRequest.data]. A false value of this
	// field indicates either that
	// [MacSignRequest.data_crc32c][google.cloud.kms.v1.MacSignRequest.data_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [MacSignRequest.data_crc32c][google.cloud.kms.v1.MacSignRequest.data_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedDataCrc32C bool `protobuf:"varint,4,opt,name=verified_data_crc32c,json=verifiedDataCrc32c,proto3" json:"verified_data_crc32c,omitempty"`
	// The [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used for signing.
	ProtectionLevel ProtectionLevel `protobuf:"varint,5,opt,name=protection_level,json=protectionLevel,proto3,enum=google.cloud.kms.v1.ProtectionLevel" json:"protection_level,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *MacSignResponse) Reset() {
	*x = MacSignResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[44]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *MacSignResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MacSignResponse) ProtoMessage() {}

func (x *MacSignResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[44]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MacSignResponse.ProtoReflect.Descriptor instead.
func (*MacSignResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{44}
}

func (x *MacSignResponse) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *MacSignResponse) GetMac() []byte {
	if x != nil {
		return x.Mac
	}
	return nil
}

func (x *MacSignResponse) GetMacCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.MacCrc32C
	}
	return nil
}

func (x *MacSignResponse) GetVerifiedDataCrc32C() bool {
	if x != nil {
		return x.VerifiedDataCrc32C
	}
	return false
}

func (x *MacSignResponse) GetProtectionLevel() ProtectionLevel {
	if x != nil {
		return x.ProtectionLevel
	}
	return ProtectionLevel_PROTECTION_LEVEL_UNSPECIFIED
}

// Response message for
// [KeyManagementService.MacVerify][google.cloud.kms.v1.KeyManagementService.MacVerify].
type MacVerifyResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used for
	// verification. Check this field to verify that the intended resource was
	// used for verification.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// This field indicates whether or not the verification operation for
	// [MacVerifyRequest.mac][google.cloud.kms.v1.MacVerifyRequest.mac] over
	// [MacVerifyRequest.data][google.cloud.kms.v1.MacVerifyRequest.data] was
	// successful.
	Success bool `protobuf:"varint,2,opt,name=success,proto3" json:"success,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [MacVerifyRequest.data_crc32c][google.cloud.kms.v1.MacVerifyRequest.data_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of the
	// [data][google.cloud.kms.v1.MacVerifyRequest.data]. A false value of this
	// field indicates either that
	// [MacVerifyRequest.data_crc32c][google.cloud.kms.v1.MacVerifyRequest.data_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [MacVerifyRequest.data_crc32c][google.cloud.kms.v1.MacVerifyRequest.data_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedDataCrc32C bool `protobuf:"varint,3,opt,name=verified_data_crc32c,json=verifiedDataCrc32c,proto3" json:"verified_data_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [MacVerifyRequest.mac_crc32c][google.cloud.kms.v1.MacVerifyRequest.mac_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of the
	// [data][google.cloud.kms.v1.MacVerifyRequest.mac]. A false value of this
	// field indicates either that
	// [MacVerifyRequest.mac_crc32c][google.cloud.kms.v1.MacVerifyRequest.mac_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [MacVerifyRequest.mac_crc32c][google.cloud.kms.v1.MacVerifyRequest.mac_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedMacCrc32C bool `protobuf:"varint,4,opt,name=verified_mac_crc32c,json=verifiedMacCrc32c,proto3" json:"verified_mac_crc32c,omitempty"`
	// Integrity verification field. This value is used for the integrity
	// verification of [MacVerifyResponse.success]. If the value of this field
	// contradicts the value of [MacVerifyResponse.success], discard the response
	// and perform a limited number of retries.
	VerifiedSuccessIntegrity bool `protobuf:"varint,5,opt,name=verified_success_integrity,json=verifiedSuccessIntegrity,proto3" json:"verified_success_integrity,omitempty"`
	// The [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used for
	// verification.
	ProtectionLevel ProtectionLevel `protobuf:"varint,6,opt,name=protection_level,json=protectionLevel,proto3,enum=google.cloud.kms.v1.ProtectionLevel" json:"protection_level,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *MacVerifyResponse) Reset() {
	*x = MacVerifyResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[45]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *MacVerifyResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MacVerifyResponse) ProtoMessage() {}

func (x *MacVerifyResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[45]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MacVerifyResponse.ProtoReflect.Descriptor instead.
func (*MacVerifyResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{45}
}

func (x *MacVerifyResponse) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *MacVerifyResponse) GetSuccess() bool {
	if x != nil {
		return x.Success
	}
	return false
}

func (x *MacVerifyResponse) GetVerifiedDataCrc32C() bool {
	if x != nil {
		return x.VerifiedDataCrc32C
	}
	return false
}

func (x *MacVerifyResponse) GetVerifiedMacCrc32C() bool {
	if x != nil {
		return x.VerifiedMacCrc32C
	}
	return false
}

func (x *MacVerifyResponse) GetVerifiedSuccessIntegrity() bool {
	if x != nil {
		return x.VerifiedSuccessIntegrity
	}
	return false
}

func (x *MacVerifyResponse) GetProtectionLevel() ProtectionLevel {
	if x != nil {
		return x.ProtectionLevel
	}
	return ProtectionLevel_PROTECTION_LEVEL_UNSPECIFIED
}

// Response message for
// [KeyManagementService.Decapsulate][google.cloud.kms.v1.KeyManagementService.Decapsulate].
type DecapsulateResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The resource name of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used for
	// decapsulation. Check this field to verify that the intended resource was
	// used for decapsulation.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The decapsulated shared_secret originally encapsulated with the matching
	// public key.
	SharedSecret []byte `protobuf:"bytes,2,opt,name=shared_secret,json=sharedSecret,proto3" json:"shared_secret,omitempty"`
	// Integrity verification field. A CRC32C checksum of the returned
	// [DecapsulateResponse.shared_secret][google.cloud.kms.v1.DecapsulateResponse.shared_secret].
	// An integrity check of
	// [DecapsulateResponse.shared_secret][google.cloud.kms.v1.DecapsulateResponse.shared_secret]
	// can be performed by computing the CRC32C checksum of
	// [DecapsulateResponse.shared_secret][google.cloud.kms.v1.DecapsulateResponse.shared_secret]
	// and comparing your results to this field. Discard the response in case of
	// non-matching checksum values, and perform a limited number of retries. A
	// persistent mismatch may indicate an issue in your computation of the CRC32C
	// checksum. Note: receiving this response message indicates that
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] is able to
	// successfully decrypt the
	// [ciphertext][google.cloud.kms.v1.DecapsulateRequest.ciphertext]. Note: This
	// field is defined as int64 for reasons of compatibility across different
	// languages. However, it is a non-negative integer, which will never exceed
	// 2^32-1, and can be safely downconverted to uint32 in languages that support
	// this type.
	SharedSecretCrc32C *int64 `protobuf:"varint,3,opt,name=shared_secret_crc32c,json=sharedSecretCrc32c,proto3,oneof" json:"shared_secret_crc32c,omitempty"`
	// Integrity verification field. A flag indicating whether
	// [DecapsulateRequest.ciphertext_crc32c][google.cloud.kms.v1.DecapsulateRequest.ciphertext_crc32c]
	// was received by
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService] and used
	// for the integrity verification of the
	// [ciphertext][google.cloud.kms.v1.DecapsulateRequest.ciphertext]. A false
	// value of this field indicates either that
	// [DecapsulateRequest.ciphertext_crc32c][google.cloud.kms.v1.DecapsulateRequest.ciphertext_crc32c]
	// was left unset or that it was not delivered to
	// [KeyManagementService][google.cloud.kms.v1.KeyManagementService]. If you've
	// set
	// [DecapsulateRequest.ciphertext_crc32c][google.cloud.kms.v1.DecapsulateRequest.ciphertext_crc32c]
	// but this field is still false, discard the response and perform a limited
	// number of retries.
	VerifiedCiphertextCrc32C bool `protobuf:"varint,4,opt,name=verified_ciphertext_crc32c,json=verifiedCiphertextCrc32c,proto3" json:"verified_ciphertext_crc32c,omitempty"`
	// The [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] of the
	// [CryptoKeyVersion][google.cloud.kms.v1.CryptoKeyVersion] used in
	// decapsulation.
	ProtectionLevel ProtectionLevel `protobuf:"varint,5,opt,name=protection_level,json=protectionLevel,proto3,enum=google.cloud.kms.v1.ProtectionLevel" json:"protection_level,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *DecapsulateResponse) Reset() {
	*x = DecapsulateResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[46]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DecapsulateResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DecapsulateResponse) ProtoMessage() {}

func (x *DecapsulateResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[46]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DecapsulateResponse.ProtoReflect.Descriptor instead.
func (*DecapsulateResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{46}
}

func (x *DecapsulateResponse) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *DecapsulateResponse) GetSharedSecret() []byte {
	if x != nil {
		return x.SharedSecret
	}
	return nil
}

func (x *DecapsulateResponse) GetSharedSecretCrc32C() int64 {
	if x != nil && x.SharedSecretCrc32C != nil {
		return *x.SharedSecretCrc32C
	}
	return 0
}

func (x *DecapsulateResponse) GetVerifiedCiphertextCrc32C() bool {
	if x != nil {
		return x.VerifiedCiphertextCrc32C
	}
	return false
}

func (x *DecapsulateResponse) GetProtectionLevel() ProtectionLevel {
	if x != nil {
		return x.ProtectionLevel
	}
	return ProtectionLevel_PROTECTION_LEVEL_UNSPECIFIED
}

// Response message for
// [KeyManagementService.GenerateRandomBytes][google.cloud.kms.v1.KeyManagementService.GenerateRandomBytes].
type GenerateRandomBytesResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The generated data.
	Data []byte `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// Integrity verification field. A CRC32C checksum of the returned
	// [GenerateRandomBytesResponse.data][google.cloud.kms.v1.GenerateRandomBytesResponse.data].
	// An integrity check of
	// [GenerateRandomBytesResponse.data][google.cloud.kms.v1.GenerateRandomBytesResponse.data]
	// can be performed by computing the CRC32C checksum of
	// [GenerateRandomBytesResponse.data][google.cloud.kms.v1.GenerateRandomBytesResponse.data]
	// and comparing your results to this field. Discard the response in case of
	// non-matching checksum values, and perform a limited number of retries. A
	// persistent mismatch may indicate an issue in your computation of the CRC32C
	// checksum. Note: This field is defined as int64 for reasons of compatibility
	// across different languages. However, it is a non-negative integer, which
	// will never exceed 2^32-1, and can be safely downconverted to uint32 in
	// languages that support this type.
	DataCrc32C    *wrapperspb.Int64Value `protobuf:"bytes,3,opt,name=data_crc32c,json=dataCrc32c,proto3" json:"data_crc32c,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GenerateRandomBytesResponse) Reset() {
	*x = GenerateRandomBytesResponse{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[47]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GenerateRandomBytesResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GenerateRandomBytesResponse) ProtoMessage() {}

func (x *GenerateRandomBytesResponse) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[47]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GenerateRandomBytesResponse.ProtoReflect.Descriptor instead.
func (*GenerateRandomBytesResponse) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{47}
}

func (x *GenerateRandomBytesResponse) GetData() []byte {
	if x != nil {
		return x.Data
	}
	return nil
}

func (x *GenerateRandomBytesResponse) GetDataCrc32C() *wrapperspb.Int64Value {
	if x != nil {
		return x.DataCrc32C
	}
	return nil
}

// A [Digest][google.cloud.kms.v1.Digest] holds a cryptographic message digest.
type Digest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Required. The message digest.
	//
	// Types that are valid to be assigned to Digest:
	//
	//	*Digest_Sha256
	//	*Digest_Sha384
	//	*Digest_Sha512
	//	*Digest_ExternalMu
	Digest        isDigest_Digest `protobuf_oneof:"digest"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Digest) Reset() {
	*x = Digest{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[48]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Digest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Digest) ProtoMessage() {}

func (x *Digest) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[48]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Digest.ProtoReflect.Descriptor instead.
func (*Digest) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{48}
}

func (x *Digest) GetDigest() isDigest_Digest {
	if x != nil {
		return x.Digest
	}
	return nil
}

func (x *Digest) GetSha256() []byte {
	if x != nil {
		if x, ok := x.Digest.(*Digest_Sha256); ok {
			return x.Sha256
		}
	}
	return nil
}

func (x *Digest) GetSha384() []byte {
	if x != nil {
		if x, ok := x.Digest.(*Digest_Sha384); ok {
			return x.Sha384
		}
	}
	return nil
}

func (x *Digest) GetSha512() []byte {
	if x != nil {
		if x, ok := x.Digest.(*Digest_Sha512); ok {
			return x.Sha512
		}
	}
	return nil
}

func (x *Digest) GetExternalMu() []byte {
	if x != nil {
		if x, ok := x.Digest.(*Digest_ExternalMu); ok {
			return x.ExternalMu
		}
	}
	return nil
}

type isDigest_Digest interface {
	isDigest_Digest()
}

type Digest_Sha256 struct {
	// A message digest produced with the SHA-256 algorithm.
	Sha256 []byte `protobuf:"bytes,1,opt,name=sha256,proto3,oneof"`
}

type Digest_Sha384 struct {
	// A message digest produced with the SHA-384 algorithm.
	Sha384 []byte `protobuf:"bytes,2,opt,name=sha384,proto3,oneof"`
}

type Digest_Sha512 struct {
	// A message digest produced with the SHA-512 algorithm.
	Sha512 []byte `protobuf:"bytes,3,opt,name=sha512,proto3,oneof"`
}

type Digest_ExternalMu struct {
	// A message digest produced with SHAKE-256, to be used with ML-DSA
	// external-μ algorithms only. See "message representative" note in
	// section 6.2, algorithm 7 of the FIPS-204 standard:
	// https://doi.org/10.6028/nist.fips.204
	ExternalMu []byte `protobuf:"bytes,4,opt,name=external_mu,json=externalMu,proto3,oneof"`
}

func (*Digest_Sha256) isDigest_Digest() {}

func (*Digest_Sha384) isDigest_Digest() {}

func (*Digest_Sha512) isDigest_Digest() {}

func (*Digest_ExternalMu) isDigest_Digest() {}

// Cloud KMS metadata for the given
// [google.cloud.location.Location][google.cloud.location.Location].
type LocationMetadata struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Indicates whether [CryptoKeys][google.cloud.kms.v1.CryptoKey] with
	// [protection_level][google.cloud.kms.v1.CryptoKeyVersionTemplate.protection_level]
	// [HSM][google.cloud.kms.v1.ProtectionLevel.HSM] can be created in this
	// location.
	HsmAvailable bool `protobuf:"varint,1,opt,name=hsm_available,json=hsmAvailable,proto3" json:"hsm_available,omitempty"`
	// Indicates whether [CryptoKeys][google.cloud.kms.v1.CryptoKey] with
	// [protection_level][google.cloud.kms.v1.CryptoKeyVersionTemplate.protection_level]
	// [EXTERNAL][google.cloud.kms.v1.ProtectionLevel.EXTERNAL] can be created in
	// this location.
	EkmAvailable bool `protobuf:"varint,2,opt,name=ekm_available,json=ekmAvailable,proto3" json:"ekm_available,omitempty"`
	// Indicates whether [CryptoKeys][google.cloud.kms.v1.CryptoKey] with
	// [protection_level][google.cloud.kms.v1.CryptoKeyVersionTemplate.protection_level]
	// [HSM_SINGLE_TENANT][google.cloud.kms.v1.ProtectionLevel.HSM_SINGLE_TENANT]
	// can be created in this location.
	HsmSingleTenantAvailable bool `protobuf:"varint,3,opt,name=hsm_single_tenant_available,json=hsmSingleTenantAvailable,proto3" json:"hsm_single_tenant_available,omitempty"`
	unknownFields            protoimpl.UnknownFields
	sizeCache                protoimpl.SizeCache
}

func (x *LocationMetadata) Reset() {
	*x = LocationMetadata{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[49]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *LocationMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*LocationMetadata) ProtoMessage() {}

func (x *LocationMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[49]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use LocationMetadata.ProtoReflect.Descriptor instead.
func (*LocationMetadata) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{49}
}

func (x *LocationMetadata) GetHsmAvailable() bool {
	if x != nil {
		return x.HsmAvailable
	}
	return false
}

func (x *LocationMetadata) GetEkmAvailable() bool {
	if x != nil {
		return x.EkmAvailable
	}
	return false
}

func (x *LocationMetadata) GetHsmSingleTenantAvailable() bool {
	if x != nil {
		return x.HsmSingleTenantAvailable
	}
	return false
}

// Represents the metadata of the
// [KeyManagementService.DeleteCryptoKey][google.cloud.kms.v1.KeyManagementService.DeleteCryptoKey]
// long-running operation.
type DeleteCryptoKeyMetadata struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Output only. The resource name of the
	// [RetiredResource][google.cloud.kms.v1.RetiredResource] created as a result
	// of this operation, in the format
	// `projects/*/locations/*/retiredResources/*`.
	RetiredResource string `protobuf:"bytes,1,opt,name=retired_resource,json=retiredResource,proto3" json:"retired_resource,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *DeleteCryptoKeyMetadata) Reset() {
	*x = DeleteCryptoKeyMetadata{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[50]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteCryptoKeyMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteCryptoKeyMetadata) ProtoMessage() {}

func (x *DeleteCryptoKeyMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[50]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteCryptoKeyMetadata.ProtoReflect.Descriptor instead.
func (*DeleteCryptoKeyMetadata) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{50}
}

func (x *DeleteCryptoKeyMetadata) GetRetiredResource() string {
	if x != nil {
		return x.RetiredResource
	}
	return ""
}

// Represents the metadata of the
// [KeyManagementService.DeleteCryptoKeyVersion][google.cloud.kms.v1.KeyManagementService.DeleteCryptoKeyVersion]
// long-running operation.
type DeleteCryptoKeyVersionMetadata struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DeleteCryptoKeyVersionMetadata) Reset() {
	*x = DeleteCryptoKeyVersionMetadata{}
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[51]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteCryptoKeyVersionMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteCryptoKeyVersionMetadata) ProtoMessage() {}

func (x *DeleteCryptoKeyVersionMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_kms_v1_service_proto_msgTypes[51]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteCryptoKeyVersionMetadata.ProtoReflect.Descriptor instead.
func (*DeleteCryptoKeyVersionMetadata) Descriptor() ([]byte, []int) {
	return file_google_cloud_kms_v1_service_proto_rawDescGZIP(), []int{51}
}

var File_google_cloud_kms_v1_service_proto protoreflect.FileDescriptor

const file_google_cloud_kms_v1_service_proto_rawDesc = "" +
	"\n" +
	"!google/cloud/kms/v1/service.proto\x12\x13google.cloud.kms.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a#google/cloud/kms/v1/resources.proto\x1a#google/longrunning/operations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xdb\x01\n" +
	"\x13ListKeyRingsRequest\x12A\n" +
	"\x06parent\x18\x01 \x01(\tB)\xe0A\x02\xfaA#\n" +
	"!locations.googleapis.com/LocationR\x06parent\x12 \n" +
	"\tpage_size\x18\x02 \x01(\x05B\x03\xe0A\x01R\bpageSize\x12\"\n" +
	"\n" +
	"page_token\x18\x03 \x01(\tB\x03\xe0A\x01R\tpageToken\x12\x1b\n" +
	"\x06filter\x18\x04 \x01(\tB\x03\xe0A\x01R\x06filter\x12\x1e\n" +
	"\border_by\x18\x05 \x01(\tB\x03\xe0A\x01R\aorderBy\"\xba\x02\n" +
	"\x15ListCryptoKeysRequest\x12?\n" +
	"\x06parent\x18\x01 \x01(\tB'\xe0A\x02\xfaA!\n" +
	"\x1fcloudkms.googleapis.com/KeyRingR\x06parent\x12 \n" +
	"\tpage_size\x18\x02 \x01(\x05B\x03\xe0A\x01R\bpageSize\x12\"\n" +
	"\n" +
	"page_token\x18\x03 \x01(\tB\x03\xe0A\x01R\tpageToken\x12]\n" +
	"\fversion_view\x18\x04 \x01(\x0e2:.google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionViewR\vversionView\x12\x1b\n" +
	"\x06filter\x18\x05 \x01(\tB\x03\xe0A\x01R\x06filter\x12\x1e\n" +
	"\border_by\x18\x06 \x01(\tB\x03\xe0A\x01R\aorderBy\"\xb4\x02\n" +
	"\x1cListCryptoKeyVersionsRequest\x12A\n" +
	"\x06parent\x18\x01 \x01(\tB)\xe0A\x02\xfaA#\n" +
	"!cloudkms.googleapis.com/CryptoKeyR\x06parent\x12 \n" +
	"\tpage_size\x18\x02 \x01(\x05B\x03\xe0A\x01R\bpageSize\x12\"\n" +
	"\n" +
	"page_token\x18\x03 \x01(\tB\x03\xe0A\x01R\tpageToken\x12N\n" +
	"\x04view\x18\x04 \x01(\x0e2:.google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionViewR\x04view\x12\x1b\n" +
	"\x06filter\x18\x05 \x01(\tB\x03\xe0A\x01R\x06filter\x12\x1e\n" +
	"\border_by\x18\x06 \x01(\tB\x03\xe0A\x01R\aorderBy\"\xdb\x01\n" +
	"\x15ListImportJobsRequest\x12?\n" +
	"\x06parent\x18\x01 \x01(\tB'\xe0A\x02\xfaA!\n" +
	"\x1fcloudkms.googleapis.com/KeyRingR\x06parent\x12 \n" +
	"\tpage_size\x18\x02 \x01(\x05B\x03\xe0A\x01R\bpageSize\x12\"\n" +
	"\n" +
	"page_token\x18\x03 \x01(\tB\x03\xe0A\x01R\tpageToken\x12\x1b\n" +
	"\x06filter\x18\x04 \x01(\tB\x03\xe0A\x01R\x06filter\x12\x1e\n" +
	"\border_by\x18\x05 \x01(\tB\x03\xe0A\x01R\aorderBy\"\xac\x01\n" +
	"\x1bListRetiredResourcesRequest\x12G\n" +
	"\x06parent\x18\x01 \x01(\tB/\xe0A\x02\xfaA)\x12'cloudkms.googleapis.com/RetiredResourceR\x06parent\x12 \n" +
	"\tpage_size\x18\x02 \x01(\x05B\x03\xe0A\x01R\bpageSize\x12\"\n" +
	"\n" +
	"page_token\x18\x03 \x01(\tB\x03\xe0A\x01R\tpageToken\"\x98\x01\n" +
	"\x14ListKeyRingsResponse\x129\n" +
	"\tkey_rings\x18\x01 \x03(\v2\x1c.google.cloud.kms.v1.KeyRingR\bkeyRings\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n" +
	"\n" +
	"total_size\x18\x03 \x01(\x05R\ttotalSize\"\xa0\x01\n" +
	"\x16ListCryptoKeysResponse\x12?\n" +
	"\vcrypto_keys\x18\x01 \x03(\v2\x1e.google.cloud.kms.v1.CryptoKeyR\n" +
	"cryptoKeys\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n" +
	"\n" +
	"total_size\x18\x03 \x01(\x05R\ttotalSize\"\xbd\x01\n" +
	"\x1dListCryptoKeyVersionsResponse\x12U\n" +
	"\x13crypto_key_versions\x18\x01 \x03(\v2%.google.cloud.kms.v1.CryptoKeyVersionR\x11cryptoKeyVersions\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n" +
	"\n" +
	"total_size\x18\x03 \x01(\x05R\ttotalSize\"\xa0\x01\n" +
	"\x16ListImportJobsResponse\x12?\n" +
	"\vimport_jobs\x18\x01 \x03(\v2\x1e.google.cloud.kms.v1.ImportJobR\n" +
	"importJobs\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n" +
	"\n" +
	"total_size\x18\x03 \x01(\x05R\ttotalSize\"\xb8\x01\n" +
	"\x1cListRetiredResourcesResponse\x12Q\n" +
	"\x11retired_resources\x18\x01 \x03(\v2$.google.cloud.kms.v1.RetiredResourceR\x10retiredResources\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n" +
	"\n" +
	"total_size\x18\x03 \x01(\x03R\ttotalSize\"P\n" +
	"\x11GetKeyRingRequest\x12;\n" +
	"\x04name\x18\x01 \x01(\tB'\xe0A\x02\xfaA!\n" +
	"\x1fcloudkms.googleapis.com/KeyRingR\x04name\"T\n" +
	"\x13GetCryptoKeyRequest\x12=\n" +
	"\x04name\x18\x01 \x01(\tB)\xe0A\x02\xfaA#\n" +
	"!cloudkms.googleapis.com/CryptoKeyR\x04name\"b\n" +
	"\x1aGetCryptoKeyVersionRequest\x12D\n" +
	"\x04name\x18\x01 \x01(\tB0\xe0A\x02\xfaA*\n" +
	"(cloudkms.googleapis.com/CryptoKeyVersionR\x04name\"\xbc\x01\n" +
	"\x13GetPublicKeyRequest\x12D\n" +
	"\x04name\x18\x01 \x01(\tB0\xe0A\x02\xfaA*\n" +
	"(cloudkms.googleapis.com/CryptoKeyVersionR\x04name\x12_\n" +
	"\x11public_key_format\x18\x02 \x01(\x0e2..google.cloud.kms.v1.PublicKey.PublicKeyFormatB\x03\xe0A\x01R\x0fpublicKeyFormat\"\xb5\x01\n" +
	"\x13GetImportJobRequest\x12=\n" +
	"\x04name\x18\x01 \x01(\tB)\xe0A\x02\xfaA#\n" +
	"!cloudkms.googleapis.com/ImportJobR\x04name\x12_\n" +
	"\x11public_key_format\x18\x02 \x01(\x0e2..google.cloud.kms.v1.PublicKey.PublicKeyFormatB\x03\xe0A\x01R\x0fpublicKeyFormat\"`\n" +
	"\x19GetRetiredResourceRequest\x12C\n" +
	"\x04name\x18\x01 \x01(\tB/\xe0A\x02\xfaA)\n" +
	"'cloudkms.googleapis.com/RetiredResourceR\x04name\"\xbc\x01\n" +
	"\x14CreateKeyRingRequest\x12A\n" +
	"\x06parent\x18\x01 \x01(\tB)\xe0A\x02\xfaA#\n" +
	"!locations.googleapis.com/LocationR\x06parent\x12#\n" +
	"\vkey_ring_id\x18\x02 \x01(\tB\x03\xe0A\x02R\tkeyRingId\x12<\n" +
	"\bkey_ring\x18\x03 \x01(\v2\x1c.google.cloud.kms.v1.KeyRingB\x03\xe0A\x02R\akeyRing\"\x89\x02\n" +
	"\x16CreateCryptoKeyRequest\x12?\n" +
	"\x06parent\x18\x01 \x01(\tB'\xe0A\x02\xfaA!\n" +
	"\x1fcloudkms.googleapis.com/KeyRingR\x06parent\x12'\n" +
	"\rcrypto_key_id\x18\x02 \x01(\tB\x03\xe0A\x02R\vcryptoKeyId\x12B\n" +
	"\n" +
	"crypto_key\x18\x03 \x01(\v2\x1e.google.cloud.kms.v1.CryptoKeyB\x03\xe0A\x02R\tcryptoKey\x12A\n" +
	"\x1dskip_initial_version_creation\x18\x05 \x01(\bR\x1askipInitialVersionCreation\"\xbc\x01\n" +
	"\x1dCreateCryptoKeyVersionRequest\x12A\n" +
	"\x06parent\x18\x01 \x01(\tB)\xe0A\x02\xfaA#\n" +
	"!cloudkms.googleapis.com/CryptoKeyR\x06parent\x12X\n" +
	"\x12crypto_key_version\x18\x02 \x01(\v2%.google.cloud.kms.v1.CryptoKeyVersionB\x03\xe0A\x02R\x10cryptoKeyVersion\"W\n" +
	"\x16DeleteCryptoKeyRequest\x12=\n" +
	"\x04name\x18\x01 \x01(\tB)\xe0A\x02\xfaA#\n" +
	"!cloudkms.googleapis.com/CryptoKeyR\x04name\"e\n" +
	"\x1dDeleteCryptoKeyVersionRequest\x12D\n" +
	"\x04name\x18\x01 \x01(\tB0\xe0A\x02\xfaA*\n" +
	"(cloudkms.googleapis.com/CryptoKeyVersionR\x04name\"\xbe\x03\n" +
	"\x1dImportCryptoKeyVersionRequest\x12A\n" +
	"\x06parent\x18\x01 \x01(\tB)\xe0A\x02\xfaA#\n" +
	"!cloudkms.googleapis.com/CryptoKeyR\x06parent\x12^\n" +
	"\x12crypto_key_version\x18\x06 \x01(\tB0\xe0A\x01\xfaA*\n" +
	"(cloudkms.googleapis.com/CryptoKeyVersionR\x10cryptoKeyVersion\x12b\n" +
	"\talgorithm\x18\x02 \x01(\x0e2?.google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionAlgorithmB\x03\xe0A\x02R\talgorithm\x12\"\n" +
	"\n" +
	"import_job\x18\x04 \x01(\tB\x03\xe0A\x02R\timportJob\x12$\n" +
	"\vwrapped_key\x18\b \x01(\fB\x03\xe0A\x01R\n" +
	"wrappedKey\x124\n" +
	"\x13rsa_aes_wrapped_key\x18\x05 \x01(\fB\x03\xe0A\x01H\x00R\x10rsaAesWrappedKeyB\x16\n" +
	"\x14wrapped_key_material\"\xc6\x01\n" +
	"\x16CreateImportJobRequest\x12?\n" +
	"\x06parent\x18\x01 \x01(\tB'\xe0A\x02\xfaA!\n" +
	"\x1fcloudkms.googleapis.com/KeyRingR\x06parent\x12'\n" +
	"\rimport_job_id\x18\x02 \x01(\tB\x03\xe0A\x02R\vimportJobId\x12B\n" +
	"\n" +
	"import_job\x18\x03 \x01(\v2\x1e.google.cloud.kms.v1.ImportJobB\x03\xe0A\x02R\timportJob\"\x9e\x01\n" +
	"\x16UpdateCryptoKeyRequest\x12B\n" +
	"\n" +
	"crypto_key\x18\x01 \x01(\v2\x1e.google.cloud.kms.v1.CryptoKeyB\x03\xe0A\x02R\tcryptoKey\x12@\n" +
	"\vupdate_mask\x18\x02 \x01(\v2\x1a.google.protobuf.FieldMaskB\x03\xe0A\x02R\n" +
	"updateMask\"\xbb\x01\n" +
	"\x1dUpdateCryptoKeyVersionRequest\x12X\n" +
	"\x12crypto_key_version\x18\x01 \x01(\v2%.google.cloud.kms.v1.CryptoKeyVersionB\x03\xe0A\x02R\x10cryptoKeyVersion\x12@\n" +
	"\vupdate_mask\x18\x02 \x01(\v2\x1a.google.protobuf.FieldMaskB\x03\xe0A\x02R\n" +
	"updateMask\"\x9d\x01\n" +
	"$UpdateCryptoKeyPrimaryVersionRequest\x12=\n" +
	"\x04name\x18\x01 \x01(\tB)\xe0A\x02\xfaA#\n" +
	"!cloudkms.googleapis.com/CryptoKeyR\x04name\x126\n" +
	"\x15crypto_key_version_id\x18\x02 \x01(\tB\x03\xe0A\x02R\x12cryptoKeyVersionId\"f\n" +
	"\x1eDestroyCryptoKeyVersionRequest\x12D\n" +
	"\x04name\x18\x01 \x01(\tB0\xe0A\x02\xfaA*\n" +
	"(cloudkms.googleapis.com/CryptoKeyVersionR\x04name\"f\n" +
	"\x1eRestoreCryptoKeyVersionRequest\x12D\n" +
	"\x04name\x18\x01 \x01(\tB0\xe0A\x02\xfaA*\n" +
	"(cloudkms.googleapis.com/CryptoKeyVersionR\x04name\"\xdb\x02\n" +
	"\x0eEncryptRequest\x12\x1d\n" +
	"\x04name\x18\x01 \x01(\tB\t\xe0A\x02\xfaA\x03\n" +
	"\x01*R\x04name\x12!\n" +
	"\tplaintext\x18\x02 \x01(\fB\x03\xe0A\x02R\tplaintext\x12G\n" +
	"\x1dadditional_authenticated_data\x18\x03 \x01(\fB\x03\xe0A\x01R\x1badditionalAuthenticatedData\x12K\n" +
	"\x10plaintext_crc32c\x18\a \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\x0fplaintextCrc32c\x12q\n" +
	"$additional_authenticated_data_crc32c\x18\b \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R!additionalAuthenticatedDataCrc32c\"\xff\x02\n" +
	"\x0eDecryptRequest\x12=\n" +
	"\x04name\x18\x01 \x01(\tB)\xe0A\x02\xfaA#\n" +
	"!cloudkms.googleapis.com/CryptoKeyR\x04name\x12#\n" +
	"\n" +
	"ciphertext\x18\x02 \x01(\fB\x03\xe0A\x02R\n" +
	"ciphertext\x12G\n" +
	"\x1dadditional_authenticated_data\x18\x03 \x01(\fB\x03\xe0A\x01R\x1badditionalAuthenticatedData\x12M\n" +
	"\x11ciphertext_crc32c\x18\x05 \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\x10ciphertextCrc32c\x12q\n" +
	"$additional_authenticated_data_crc32c\x18\x06 \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R!additionalAuthenticatedDataCrc32c\"\xf6\x03\n" +
	"\x11RawEncryptRequest\x12\x17\n" +
	"\x04name\x18\x01 \x01(\tB\x03\xe0A\x02R\x04name\x12!\n" +
	"\tplaintext\x18\x02 \x01(\fB\x03\xe0A\x02R\tplaintext\x12G\n" +
	"\x1dadditional_authenticated_data\x18\x03 \x01(\fB\x03\xe0A\x01R\x1badditionalAuthenticatedData\x12K\n" +
	"\x10plaintext_crc32c\x18\x04 \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\x0fplaintextCrc32c\x12q\n" +
	"$additional_authenticated_data_crc32c\x18\x05 \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R!additionalAuthenticatedDataCrc32c\x128\n" +
	"\x15initialization_vector\x18\x06 \x01(\fB\x03\xe0A\x01R\x14initializationVector\x12b\n" +
	"\x1cinitialization_vector_crc32c\x18\a \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\x1ainitializationVectorCrc32c\"\x99\x04\n" +
	"\x11RawDecryptRequest\x12\x17\n" +
	"\x04name\x18\x01 \x01(\tB\x03\xe0A\x02R\x04name\x12#\n" +
	"\n" +
	"ciphertext\x18\x02 \x01(\fB\x03\xe0A\x02R\n" +
	"ciphertext\x12G\n" +
	"\x1dadditional_authenticated_data\x18\x03 \x01(\fB\x03\xe0A\x01R\x1badditionalAuthenticatedData\x128\n" +
	"\x15initialization_vector\x18\x04 \x01(\fB\x03\xe0A\x02R\x14initializationVector\x12\x1d\n" +
	"\n" +
	"tag_length\x18\x05 \x01(\x05R\ttagLength\x12M\n" +
	"\x11ciphertext_crc32c\x18\x06 \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\x10ciphertextCrc32c\x12q\n" +
	"$additional_authenticated_data_crc32c\x18\a \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R!additionalAuthenticatedDataCrc32c\x12b\n" +
	"\x1cinitialization_vector_crc32c\x18\b \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\x1ainitializationVectorCrc32c\"\xba\x02\n" +
	"\x15AsymmetricSignRequest\x12D\n" +
	"\x04name\x18\x01 \x01(\tB0\xe0A\x02\xfaA*\n" +
	"(cloudkms.googleapis.com/CryptoKeyVersionR\x04name\x128\n" +
	"\x06digest\x18\x03 \x01(\v2\x1b.google.cloud.kms.v1.DigestB\x03\xe0A\x01R\x06digest\x12E\n" +
	"\rdigest_crc32c\x18\x04 \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\fdigestCrc32c\x12\x17\n" +
	"\x04data\x18\x06 \x01(\fB\x03\xe0A\x01R\x04data\x12A\n" +
	"\vdata_crc32c\x18\a \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\n" +
	"dataCrc32c\"\xd4\x01\n" +
	"\x18AsymmetricDecryptRequest\x12D\n" +
	"\x04name\x18\x01 \x01(\tB0\xe0A\x02\xfaA*\n" +
	"(cloudkms.googleapis.com/CryptoKeyVersionR\x04name\x12#\n" +
	"\n" +
	"ciphertext\x18\x03 \x01(\fB\x03\xe0A\x02R\n" +
	"ciphertext\x12M\n" +
	"\x11ciphertext_crc32c\x18\x04 \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\x10ciphertextCrc32c\"\xb2\x01\n" +
	"\x0eMacSignRequest\x12D\n" +
	"\x04name\x18\x01 \x01(\tB0\xe0A\x02\xfaA*\n" +
	"(cloudkms.googleapis.com/CryptoKeyVersionR\x04name\x12\x17\n" +
	"\x04data\x18\x02 \x01(\fB\x03\xe0A\x02R\x04data\x12A\n" +
	"\vdata_crc32c\x18\x03 \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\n" +
	"dataCrc32c\"\x8c\x02\n" +
	"\x10MacVerifyRequest\x12D\n" +
	"\x04name\x18\x01 \x01(\tB0\xe0A\x02\xfaA*\n" +
	"(cloudkms.googleapis.com/CryptoKeyVersionR\x04name\x12\x17\n" +
	"\x04data\x18\x02 \x01(\fB\x03\xe0A\x02R\x04data\x12A\n" +
	"\vdata_crc32c\x18\x03 \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\n" +
	"dataCrc32c\x12\x15\n" +
	"\x03mac\x18\x04 \x01(\fB\x03\xe0A\x02R\x03mac\x12?\n" +
	"\n" +
	"mac_crc32c\x18\x05 \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\tmacCrc32c\"\xce\x01\n" +
	"\x12DecapsulateRequest\x12D\n" +
	"\x04name\x18\x01 \x01(\tB0\xe0A\x02\xfaA*\n" +
	"(cloudkms.googleapis.com/CryptoKeyVersionR\x04name\x12#\n" +
	"\n" +
	"ciphertext\x18\x02 \x01(\fB\x03\xe0A\x02R\n" +
	"ciphertext\x12M\n" +
	"\x11ciphertext_crc32c\x18\x03 \x01(\v2\x1b.google.protobuf.Int64ValueB\x03\xe0A\x01R\x10ciphertextCrc32c\"\xac\x01\n" +
	"\x1aGenerateRandomBytesRequest\x12\x1a\n" +
	"\blocation\x18\x01 \x01(\tR\blocation\x12!\n" +
	"\flength_bytes\x18\x02 \x01(\x05R\vlengthBytes\x12O\n" +
	"\x10protection_level\x18\x03 \x01(\x0e2$.google.cloud.kms.v1.ProtectionLevelR\x0fprotectionLevel\"\xfe\x02\n" +
	"\x0fEncryptResponse\x12\x12\n" +
	"\x04name\x18\x01 \x01(\tR\x04name\x12\x1e\n" +
	"\n" +
	"ciphertext\x18\x02 \x01(\fR\n" +
	"ciphertext\x12H\n" +
	"\x11ciphertext_crc32c\x18\x04 \x01(\v2\x1b.google.protobuf.Int64ValueR\x10ciphertextCrc32c\x12:\n" +
	"\x19verified_plaintext_crc32c\x18\x05 \x01(\bR\x17verifiedPlaintextCrc32c\x12`\n" +
	"-verified_additional_authenticated_data_crc32c\x18\x06 \x01(\bR)verifiedAdditionalAuthenticatedDataCrc32c\x12O\n" +
	"\x10protection_level\x18\a \x01(\x0e2$.google.cloud.kms.v1.ProtectionLevelR\x0fprotectionLevel\"\xeb\x01\n" +
	"\x0fDecryptResponse\x12\x1c\n" +
	"\tplaintext\x18\x01 \x01(\fR\tplaintext\x12F\n" +
	"\x10plaintext_crc32c\x18\x02 \x01(\v2\x1b.google.protobuf.Int64ValueR\x0fplaintextCrc32c\x12!\n" +
	"\fused_primary\x18\x03 \x01(\bR\vusedPrimary\x12O\n" +
	"\x10protection_level\x18\x04 \x01(\x0e2$.google.cloud.kms.v1.ProtectionLevelR\x0fprotectionLevel\"\x87\x05\n" +
	"\x12RawEncryptResponse\x12\x1e\n" +
	"\n" +
	"ciphertext\x18\x01 \x01(\fR\n" +
	"ciphertext\x123\n" +
	"\x15initialization_vector\x18\x02 \x01(\fR\x14initializationVector\x12\x1d\n" +
	"\n" +
	"tag_length\x18\x03 \x01(\x05R\ttagLength\x12H\n" +
	"\x11ciphertext_crc32c\x18\x04 \x01(\v2\x1b.google.protobuf.Int64ValueR\x10ciphertextCrc32c\x12]\n" +
	"\x1cinitialization_vector_crc32c\x18\x05 \x01(\v2\x1b.google.protobuf.Int64ValueR\x1ainitializationVectorCrc32c\x12:\n" +
	"\x19verified_plaintext_crc32c\x18\x06 \x01(\bR\x17verifiedPlaintextCrc32c\x12`\n" +
	"-verified_additional_authenticated_data_crc32c\x18\a \x01(\bR)verifiedAdditionalAuthenticatedDataCrc32c\x12Q\n" +
	"%verified_initialization_vector_crc32c\x18\n" +
	" \x01(\bR\"verifiedInitializationVectorCrc32c\x12\x12\n" +
	"\x04name\x18\b \x01(\tR\x04name\x12O\n" +
	"\x10protection_level\x18\t \x01(\x0e2$.google.cloud.kms.v1.ProtectionLevelR\x0fprotectionLevel\"\xbe\x03\n" +
	"\x12RawDecryptResponse\x12\x1c\n" +
	"\tplaintext\x18\x01 \x01(\fR\tplaintext\x12F\n" +
	"\x10plaintext_crc32c\x18\x02 \x01(\v2\x1b.google.protobuf.Int64ValueR\x0fplaintextCrc32c\x12O\n" +
	"\x10protection_level\x18\x03 \x01(\x0e2$.google.cloud.kms.v1.ProtectionLevelR\x0fprotectionLevel\x12<\n" +
	"\x1averified_ciphertext_crc32c\x18\x04 \x01(\bR\x18verifiedCiphertextCrc32c\x12`\n" +
	"-verified_additional_authenticated_data_crc32c\x18\x05 \x01(\bR)verifiedAdditionalAuthenticatedDataCrc32c\x12Q\n" +
	"%verified_initialization_vector_crc32c\x18\x06 \x01(\bR\"verifiedInitializationVectorCrc32c\"\xcb\x02\n" +
	"\x16AsymmetricSignResponse\x12\x1c\n" +
	"\tsignature\x18\x01 \x01(\fR\tsignature\x12F\n" +
	"\x10signature_crc32c\x18\x02 \x01(\v2\x1b.google.protobuf.Int64ValueR\x0fsignatureCrc32c\x124\n" +
	"\x16verified_digest_crc32c\x18\x03 \x01(\bR\x14verifiedDigestCrc32c\x12\x12\n" +
	"\x04name\x18\x04 \x01(\tR\x04name\x120\n" +
	"\x14verified_data_crc32c\x18\x05 \x01(\bR\x12verifiedDataCrc32c\x12O\n" +
	"\x10protection_level\x18\x06 \x01(\x0e2$.google.cloud.kms.v1.ProtectionLevelR\x0fprotectionLevel\"\x90\x02\n" +
	"\x19AsymmetricDecryptResponse\x12\x1c\n" +
	"\tplaintext\x18\x01 \x01(\fR\tplaintext\x12F\n" +
	"\x10plaintext_crc32c\x18\x02 \x01(\v2\x1b.google.protobuf.Int64ValueR\x0fplaintextCrc32c\x12<\n" +
	"\x1averified_ciphertext_crc32c\x18\x03 \x01(\bR\x18verifiedCiphertextCrc32c\x12O\n" +
	"\x10protection_level\x18\x04 \x01(\x0e2$.google.cloud.kms.v1.ProtectionLevelR\x0fprotectionLevel\"\xf6\x01\n" +
	"\x0fMacSignResponse\x12\x12\n" +
	"\x04name\x18\x01 \x01(\tR\x04name\x12\x10\n" +
	"\x03mac\x18\x02 \x01(\fR\x03mac\x12:\n" +
	"\n" +
	"mac_crc32c\x18\x03 \x01(\v2\x1b.google.protobuf.Int64ValueR\tmacCrc32c\x120\n" +
	"\x14verified_data_crc32c\x18\x04 \x01(\bR\x12verifiedDataCrc32c\x12O\n" +
	"\x10protection_level\x18\x05 \x01(\x0e2$.google.cloud.kms.v1.ProtectionLevelR\x0fprotectionLevel\"\xb2\x02\n" +
	"\x11MacVerifyResponse\x12\x12\n" +
	"\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n" +
	"\asuccess\x18\x02 \x01(\bR\asuccess\x120\n" +
	"\x14verified_data_crc32c\x18\x03 \x01(\bR\x12verifiedDataCrc32c\x12.\n" +
	"\x13verified_mac_crc32c\x18\x04 \x01(\bR\x11verifiedMacCrc32c\x12<\n" +
	"\x1averified_success_integrity\x18\x05 \x01(\bR\x18verifiedSuccessIntegrity\x12O\n" +
	"\x10protection_level\x18\x06 \x01(\x0e2$.google.cloud.kms.v1.ProtectionLevelR\x0fprotectionLevel\"\xad\x02\n" +
	"\x13DecapsulateResponse\x12\x12\n" +
	"\x04name\x18\x01 \x01(\tR\x04name\x12#\n" +
	"\rshared_secret\x18\x02 \x01(\fR\fsharedSecret\x125\n" +
	"\x14shared_secret_crc32c\x18\x03 \x01(\x03H\x00R\x12sharedSecretCrc32c\x88\x01\x01\x12<\n" +
	"\x1averified_ciphertext_crc32c\x18\x04 \x01(\bR\x18verifiedCiphertextCrc32c\x12O\n" +
	"\x10protection_level\x18\x05 \x01(\x0e2$.google.cloud.kms.v1.ProtectionLevelR\x0fprotectionLevelB\x17\n" +
	"\x15_shared_secret_crc32c\"o\n" +
	"\x1bGenerateRandomBytesResponse\x12\x12\n" +
	"\x04data\x18\x01 \x01(\fR\x04data\x12<\n" +
	"\vdata_crc32c\x18\x03 \x01(\v2\x1b.google.protobuf.Int64ValueR\n" +
	"dataCrc32c\"\x83\x01\n" +
	"\x06Digest\x12\x18\n" +
	"\x06sha256\x18\x01 \x01(\fH\x00R\x06sha256\x12\x18\n" +
	"\x06sha384\x18\x02 \x01(\fH\x00R\x06sha384\x12\x18\n" +
	"\x06sha512\x18\x03 \x01(\fH\x00R\x06sha512\x12!\n" +
	"\vexternal_mu\x18\x04 \x01(\fH\x00R\n" +
	"externalMuB\b\n" +
	"\x06digest\"\x9b\x01\n" +
	"\x10LocationMetadata\x12#\n" +
	"\rhsm_available\x18\x01 \x01(\bR\fhsmAvailable\x12#\n" +
	"\rekm_available\x18\x02 \x01(\bR\fekmAvailable\x12=\n" +
	"\x1bhsm_single_tenant_available\x18\x03 \x01(\bR\x18hsmSingleTenantAvailable\"u\n" +
	"\x17DeleteCryptoKeyMetadata\x12Z\n" +
	"\x10retired_resource\x18\x01 \x01(\tB/\xe0A\x03\xfaA)\n" +
	"'cloudkms.googleapis.com/RetiredResourceR\x0fretiredResource\" \n" +
	"\x1eDeleteCryptoKeyVersionMetadata2\xb46\n" +
	"\x14KeyManagementService\x12\xa2\x01\n" +
	"\fListKeyRings\x12(.google.cloud.kms.v1.ListKeyRingsRequest\x1a).google.cloud.kms.v1.ListKeyRingsResponse\"=\xdaA\x06parent\x82\xd3\xe4\x93\x02.\x12,/v1/{parent=projects/*/locations/*}/keyRings\x12\xb5\x01\n" +
	"\x0eListCryptoKeys\x12*.google.cloud.kms.v1.ListCryptoKeysRequest\x1a+.google.cloud.kms.v1.ListCryptoKeysResponse\"J\xdaA\x06parent\x82\xd3\xe4\x93\x02;\x129/v1/{parent=projects/*/locations/*/keyRings/*}/cryptoKeys\x12\xde\x01\n" +
	"\x15ListCryptoKeyVersions\x121.google.cloud.kms.v1.ListCryptoKeyVersionsRequest\x1a2.google.cloud.kms.v1.ListCryptoKeyVersionsResponse\"^\xdaA\x06parent\x82\xd3\xe4\x93\x02O\x12M/v1/{parent=projects/*/locations/*/keyRings/*/cryptoKeys/*}/cryptoKeyVersions\x12\xb5\x01\n" +
	"\x0eListImportJobs\x12*.google.cloud.kms.v1.ListImportJobsRequest\x1a+.google.cloud.kms.v1.ListImportJobsResponse\"J\xdaA\x06parent\x82\xd3\xe4\x93\x02;\x129/v1/{parent=projects/*/locations/*/keyRings/*}/importJobs\x12\xc2\x01\n" +
	"\x14ListRetiredResources\x120.google.cloud.kms.v1.ListRetiredResourcesRequest\x1a1.google.cloud.kms.v1.ListRetiredResourcesResponse\"E\xdaA\x06parent\x82\xd3\xe4\x93\x026\x124/v1/{parent=projects/*/locations/*}/retiredResources\x12\x8f\x01\n" +
	"\n" +
	"GetKeyRing\x12&.google.cloud.kms.v1.GetKeyRingRequest\x1a\x1c.google.cloud.kms.v1.KeyRing\";\xdaA\x04name\x82\xd3\xe4\x93\x02.\x12,/v1/{name=projects/*/locations/*/keyRings/*}\x12\xa2\x01\n" +
	"\fGetCryptoKey\x12(.google.cloud.kms.v1.GetCryptoKeyRequest\x1a\x1e.google.cloud.kms.v1.CryptoKey\"H\xdaA\x04name\x82\xd3\xe4\x93\x02;\x129/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*}\x12\xcb\x01\n" +
	"\x13GetCryptoKeyVersion\x12/.google.cloud.kms.v1.GetCryptoKeyVersionRequest\x1a%.google.cloud.kms.v1.CryptoKeyVersion\"\\\xdaA\x04name\x82\xd3\xe4\x93\x02O\x12M/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}\x12\xc0\x01\n" +
	"\fGetPublicKey\x12(.google.cloud.kms.v1.GetPublicKeyRequest\x1a\x1e.google.cloud.kms.v1.PublicKey\"f\xdaA\x04name\x82\xd3\xe4\x93\x02Y\x12W/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}/publicKey\x12\xa2\x01\n" +
	"\fGetImportJob\x12(.google.cloud.kms.v1.GetImportJobRequest\x1a\x1e.google.cloud.kms.v1.ImportJob\"H\xdaA\x04name\x82\xd3\xe4\x93\x02;\x129/v1/{name=projects/*/locations/*/keyRings/*/importJobs/*}\x12\xaf\x01\n" +
	"\x12GetRetiredResource\x12..google.cloud.kms.v1.GetRetiredResourceRequest\x1a$.google.cloud.kms.v1.RetiredResource\"C\xdaA\x04name\x82\xd3\xe4\x93\x026\x124/v1/{name=projects/*/locations/*/retiredResources/*}\x12\xb6\x01\n" +
	"\rCreateKeyRing\x12).google.cloud.kms.v1.CreateKeyRingRequest\x1a\x1c.google.cloud.kms.v1.KeyRing\"\\\xdaA\x1bparent,key_ring_id,key_ring\x82\xd3\xe4\x93\x028:\bkey_ring\",/v1/{parent=projects/*/locations/*}/keyRings\x12\xcf\x01\n" +
	"\x0fCreateCryptoKey\x12+.google.cloud.kms.v1.CreateCryptoKeyRequest\x1a\x1e.google.cloud.kms.v1.CryptoKey\"o\xdaA\x1fparent,crypto_key_id,crypto_key\x82\xd3\xe4\x93\x02G:\n" +
	"crypto_key\"9/v1/{parent=projects/*/locations/*/keyRings/*}/cryptoKeys\x12\xfb\x01\n" +
	"\x16CreateCryptoKeyVersion\x122.google.cloud.kms.v1.CreateCryptoKeyVersionRequest\x1a%.google.cloud.kms.v1.CryptoKeyVersion\"\x85\x01\xdaA\x19parent,crypto_key_version\x82\xd3\xe4\x93\x02c:\x12crypto_key_version\"M/v1/{parent=projects/*/locations/*/keyRings/*/cryptoKeys/*}/cryptoKeyVersions\x12\xda\x01\n" +
	"\x0fDeleteCryptoKey\x12+.google.cloud.kms.v1.DeleteCryptoKeyRequest\x1a\x1d.google.longrunning.Operation\"{\xcaA0\n" +
	"\x15google.protobuf.Empty\x12\x17DeleteCryptoKeyMetadata\xdaA\x04name\x82\xd3\xe4\x93\x02;*9/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*}\x12\x84\x02\n" +
	"\x16DeleteCryptoKeyVersion\x122.google.cloud.kms.v1.DeleteCryptoKeyVersionRequest\x1a\x1d.google.longrunning.Operation\"\x96\x01\xcaA7\n" +
	"\x15google.protobuf.Empty\x12\x1eDeleteCryptoKeyVersionMetadata\xdaA\x04name\x82\xd3\xe4\x93\x02O*M/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}\x12\xd4\x01\n" +
	"\x16ImportCryptoKeyVersion\x122.google.cloud.kms.v1.ImportCryptoKeyVersionRequest\x1a%.google.cloud.kms.v1.CryptoKeyVersion\"_\x82\xd3\xe4\x93\x02Y:\x01*\"T/v1/{parent=projects/*/locations/*/keyRings/*/cryptoKeys/*}/cryptoKeyVersions:import\x12\xcf\x01\n" +
	"\x0fCreateImportJob\x12+.google.cloud.kms.v1.CreateImportJobRequest\x1a\x1e.google.cloud.kms.v1.ImportJob\"o\xdaA\x1fparent,import_job_id,import_job\x82\xd3\xe4\x93\x02G:\n" +
	"import_job\"9/v1/{parent=projects/*/locations/*/keyRings/*}/importJobs\x12\xd1\x01\n" +
	"\x0fUpdateCryptoKey\x12+.google.cloud.kms.v1.UpdateCryptoKeyRequest\x1a\x1e.google.cloud.kms.v1.CryptoKey\"q\xdaA\x16crypto_key,update_mask\x82\xd3\xe4\x93\x02R:\n" +
	"crypto_key2D/v1/{crypto_key.name=projects/*/locations/*/keyRings/*/cryptoKeys/*}\x12\x93\x02\n" +
	"\x16UpdateCryptoKeyVersion\x122.google.cloud.kms.v1.UpdateCryptoKeyVersionRequest\x1a%.google.cloud.kms.v1.CryptoKeyVersion\"\x9d\x01\xdaA\x1ecrypto_key_version,update_mask\x82\xd3\xe4\x93\x02v:\x12crypto_key_version2`/v1/{crypto_key_version.name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}\x12\xf2\x01\n" +
	"\x1dUpdateCryptoKeyPrimaryVersion\x129.google.cloud.kms.v1.UpdateCryptoKeyPrimaryVersionRequest\x1a\x1e.google.cloud.kms.v1.CryptoKey\"v\xdaA\x1aname,crypto_key_version_id\x82\xd3\xe4\x93\x02S:\x01*\"N/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*}:updatePrimaryVersion\x12\xde\x01\n" +
	"\x17DestroyCryptoKeyVersion\x123.google.cloud.kms.v1.DestroyCryptoKeyVersionRequest\x1a%.google.cloud.kms.v1.CryptoKeyVersion\"g\xdaA\x04name\x82\xd3\xe4\x93\x02Z:\x01*\"U/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}:destroy\x12\xde\x01\n" +
	"\x17RestoreCryptoKeyVersion\x123.google.cloud.kms.v1.RestoreCryptoKeyVersionRequest\x1a%.google.cloud.kms.v1.CryptoKeyVersion\"g\xdaA\x04name\x82\xd3\xe4\x93\x02Z:\x01*\"U/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}:restore\x12\xb4\x01\n" +
	"\aEncrypt\x12#.google.cloud.kms.v1.EncryptRequest\x1a$.google.cloud.kms.v1.EncryptResponse\"^\xdaA\x0ename,plaintext\x82\xd3\xe4\x93\x02G:\x01*\"B/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/**}:encrypt\x12\xb4\x01\n" +
	"\aDecrypt\x12#.google.cloud.kms.v1.DecryptRequest\x1a$.google.cloud.kms.v1.DecryptResponse\"^\xdaA\x0fname,ciphertext\x82\xd3\xe4\x93\x02F:\x01*\"A/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*}:decrypt\x12\xc2\x01\n" +
	"\n" +
	"RawEncrypt\x12&.google.cloud.kms.v1.RawEncryptRequest\x1a'.google.cloud.kms.v1.RawEncryptResponse\"c\x82\xd3\xe4\x93\x02]:\x01*\"X/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}:rawEncrypt\x12\xc2\x01\n" +
	"\n" +
	"RawDecrypt\x12&.google.cloud.kms.v1.RawDecryptRequest\x1a'.google.cloud.kms.v1.RawDecryptResponse\"c\x82\xd3\xe4\x93\x02]:\x01*\"X/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}:rawDecrypt\x12\xe0\x01\n" +
	"\x0eAsymmetricSign\x12*.google.cloud.kms.v1.AsymmetricSignRequest\x1a+.google.cloud.kms.v1.AsymmetricSignResponse\"u\xdaA\vname,digest\x82\xd3\xe4\x93\x02a:\x01*\"\\/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}:asymmetricSign\x12\xf0\x01\n" +
	"\x11AsymmetricDecrypt\x12-.google.cloud.kms.v1.AsymmetricDecryptRequest\x1a..google.cloud.kms.v1.AsymmetricDecryptResponse\"|\xdaA\x0fname,ciphertext\x82\xd3\xe4\x93\x02d:\x01*\"_/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}:asymmetricDecrypt\x12\xc2\x01\n" +
	"\aMacSign\x12#.google.cloud.kms.v1.MacSignRequest\x1a$.google.cloud.kms.v1.MacSignResponse\"l\xdaA\tname,data\x82\xd3\xe4\x93\x02Z:\x01*\"U/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}:macSign\x12\xce\x01\n" +
	"\tMacVerify\x12%.google.cloud.kms.v1.MacVerifyRequest\x1a&.google.cloud.kms.v1.MacVerifyResponse\"r\xdaA\rname,data,mac\x82\xd3\xe4\x93\x02\\:\x01*\"W/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}:macVerify\x12\xc6\x01\n" +
	"\vDecapsulate\x12'.google.cloud.kms.v1.DecapsulateRequest\x1a(.google.cloud.kms.v1.DecapsulateResponse\"d\x82\xd3\xe4\x93\x02^:\x01*\"Y/v1/{name=projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*}:decapsulate\x12\xe7\x01\n" +
	"\x13GenerateRandomBytes\x12/.google.cloud.kms.v1.GenerateRandomBytesRequest\x1a0.google.cloud.kms.v1.GenerateRandomBytesResponse\"m\xdaA&location,length_bytes,protection_level\x82\xd3\xe4\x93\x02>:\x01*\"9/v1/{location=projects/*/locations/*}:generateRandomBytes\x1at\xcaA\x17cloudkms.googleapis.com\xd2AWhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloudkmsB|\n" +
	"\x17com.google.cloud.kms.v1B\bKmsProtoP\x01Z)cloud.google.com/go/kms/apiv1/kmspb;kmspb\xaa\x02\x13Google.Cloud.Kms.V1\xca\x02\x13Google\\Cloud\\Kms\\V1b\x06proto3"

var (
	file_google_cloud_kms_v1_service_proto_rawDescOnce sync.Once
	file_google_cloud_kms_v1_service_proto_rawDescData []byte
)

func file_google_cloud_kms_v1_service_proto_rawDescGZIP() []byte {
	file_google_cloud_kms_v1_service_proto_rawDescOnce.Do(func() {
		file_google_cloud_kms_v1_service_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_google_cloud_kms_v1_service_proto_rawDesc), len(file_google_cloud_kms_v1_service_proto_rawDesc)))
	})
	return file_google_cloud_kms_v1_service_proto_rawDescData
}

var file_google_cloud_kms_v1_service_proto_msgTypes = make([]protoimpl.MessageInfo, 52)
var file_google_cloud_kms_v1_service_proto_goTypes = []any{
	(*ListKeyRingsRequest)(nil),                     // 0: google.cloud.kms.v1.ListKeyRingsRequest
	(*ListCryptoKeysRequest)(nil),                   // 1: google.cloud.kms.v1.ListCryptoKeysRequest
	(*ListCryptoKeyVersionsRequest)(nil),            // 2: google.cloud.kms.v1.ListCryptoKeyVersionsRequest
	(*ListImportJobsRequest)(nil),                   // 3: google.cloud.kms.v1.ListImportJobsRequest
	(*ListRetiredResourcesRequest)(nil),             // 4: google.cloud.kms.v1.ListRetiredResourcesRequest
	(*ListKeyRingsResponse)(nil),                    // 5: google.cloud.kms.v1.ListKeyRingsResponse
	(*ListCryptoKeysResponse)(nil),                  // 6: google.cloud.kms.v1.ListCryptoKeysResponse
	(*ListCryptoKeyVersionsResponse)(nil),           // 7: google.cloud.kms.v1.ListCryptoKeyVersionsResponse
	(*ListImportJobsResponse)(nil),                  // 8: google.cloud.kms.v1.ListImportJobsResponse
	(*ListRetiredResourcesResponse)(nil),            // 9: google.cloud.kms.v1.ListRetiredResourcesResponse
	(*GetKeyRingRequest)(nil),                       // 10: google.cloud.kms.v1.GetKeyRingRequest
	(*GetCryptoKeyRequest)(nil),                     // 11: google.cloud.kms.v1.GetCryptoKeyRequest
	(*GetCryptoKeyVersionRequest)(nil),              // 12: google.cloud.kms.v1.GetCryptoKeyVersionRequest
	(*GetPublicKeyRequest)(nil),                     // 13: google.cloud.kms.v1.GetPublicKeyRequest
	(*GetImportJobRequest)(nil),                     // 14: google.cloud.kms.v1.GetImportJobRequest
	(*GetRetiredResourceRequest)(nil),               // 15: google.cloud.kms.v1.GetRetiredResourceRequest
	(*CreateKeyRingRequest)(nil),                    // 16: google.cloud.kms.v1.CreateKeyRingRequest
	(*CreateCryptoKeyRequest)(nil),                  // 17: google.cloud.kms.v1.CreateCryptoKeyRequest
	(*CreateCryptoKeyVersionRequest)(nil),           // 18: google.cloud.kms.v1.CreateCryptoKeyVersionRequest
	(*DeleteCryptoKeyRequest)(nil),                  // 19: google.cloud.kms.v1.DeleteCryptoKeyRequest
	(*DeleteCryptoKeyVersionRequest)(nil),           // 20: google.cloud.kms.v1.DeleteCryptoKeyVersionRequest
	(*ImportCryptoKeyVersionRequest)(nil),           // 21: google.cloud.kms.v1.ImportCryptoKeyVersionRequest
	(*CreateImportJobRequest)(nil),                  // 22: google.cloud.kms.v1.CreateImportJobRequest
	(*UpdateCryptoKeyRequest)(nil),                  // 23: google.cloud.kms.v1.UpdateCryptoKeyRequest
	(*UpdateCryptoKeyVersionRequest)(nil),           // 24: google.cloud.kms.v1.UpdateCryptoKeyVersionRequest
	(*UpdateCryptoKeyPrimaryVersionRequest)(nil),    // 25: google.cloud.kms.v1.UpdateCryptoKeyPrimaryVersionRequest
	(*DestroyCryptoKeyVersionRequest)(nil),          // 26: google.cloud.kms.v1.DestroyCryptoKeyVersionRequest
	(*RestoreCryptoKeyVersionRequest)(nil),          // 27: google.cloud.kms.v1.RestoreCryptoKeyVersionRequest
	(*EncryptRequest)(nil),                          // 28: google.cloud.kms.v1.EncryptRequest
	(*DecryptRequest)(nil),                          // 29: google.cloud.kms.v1.DecryptRequest
	(*RawEncryptRequest)(nil),                       // 30: google.cloud.kms.v1.RawEncryptRequest
	(*RawDecryptRequest)(nil),                       // 31: google.cloud.kms.v1.RawDecryptRequest
	(*AsymmetricSignRequest)(nil),                   // 32: google.cloud.kms.v1.AsymmetricSignRequest
	(*AsymmetricDecryptRequest)(nil),                // 33: google.cloud.kms.v1.AsymmetricDecryptRequest
	(*MacSignRequest)(nil),                          // 34: google.cloud.kms.v1.MacSignRequest
	(*MacVerifyRequest)(nil),                        // 35: google.cloud.kms.v1.MacVerifyRequest
	(*DecapsulateRequest)(nil),                      // 36: google.cloud.kms.v1.DecapsulateRequest
	(*GenerateRandomBytesRequest)(nil),              // 37: google.cloud.kms.v1.GenerateRandomBytesRequest
	(*EncryptResponse)(nil),                         // 38: google.cloud.kms.v1.EncryptResponse
	(*DecryptResponse)(nil),                         // 39: google.cloud.kms.v1.DecryptResponse
	(*RawEncryptResponse)(nil),                      // 40: google.cloud.kms.v1.RawEncryptResponse
	(*RawDecryptResponse)(nil),                      // 41: google.cloud.kms.v1.RawDecryptResponse
	(*AsymmetricSignResponse)(nil),                  // 42: google.cloud.kms.v1.AsymmetricSignResponse
	(*AsymmetricDecryptResponse)(nil),               // 43: google.cloud.kms.v1.AsymmetricDecryptResponse
	(*MacSignResponse)(nil),                         // 44: google.cloud.kms.v1.MacSignResponse
	(*MacVerifyResponse)(nil),                       // 45: google.cloud.kms.v1.MacVerifyResponse
	(*DecapsulateResponse)(nil),                     // 46: google.cloud.kms.v1.DecapsulateResponse
	(*GenerateRandomBytesResponse)(nil),             // 47: google.cloud.kms.v1.GenerateRandomBytesResponse
	(*Digest)(nil),                                  // 48: google.cloud.kms.v1.Digest
	(*LocationMetadata)(nil),                        // 49: google.cloud.kms.v1.LocationMetadata
	(*DeleteCryptoKeyMetadata)(nil),                 // 50: google.cloud.kms.v1.DeleteCryptoKeyMetadata
	(*DeleteCryptoKeyVersionMetadata)(nil),          // 51: google.cloud.kms.v1.DeleteCryptoKeyVersionMetadata
	(CryptoKeyVersion_CryptoKeyVersionView)(0),      // 52: google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionView
	(*KeyRing)(nil),                                 // 53: google.cloud.kms.v1.KeyRing
	(*CryptoKey)(nil),                               // 54: google.cloud.kms.v1.CryptoKey
	(*CryptoKeyVersion)(nil),                        // 55: google.cloud.kms.v1.CryptoKeyVersion
	(*ImportJob)(nil),                               // 56: google.cloud.kms.v1.ImportJob
	(*RetiredResource)(nil),                         // 57: google.cloud.kms.v1.RetiredResource
	(PublicKey_PublicKeyFormat)(0),                  // 58: google.cloud.kms.v1.PublicKey.PublicKeyFormat
	(CryptoKeyVersion_CryptoKeyVersionAlgorithm)(0), // 59: google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionAlgorithm
	(*fieldmaskpb.FieldMask)(nil),                   // 60: google.protobuf.FieldMask
	(*wrapperspb.Int64Value)(nil),                   // 61: google.protobuf.Int64Value
	(ProtectionLevel)(0),                            // 62: google.cloud.kms.v1.ProtectionLevel
	(*PublicKey)(nil),                               // 63: google.cloud.kms.v1.PublicKey
	(*longrunningpb.Operation)(nil),                 // 64: google.longrunning.Operation
}
var file_google_cloud_kms_v1_service_proto_depIdxs = []int32{
	52, // 0: google.cloud.kms.v1.ListCryptoKeysRequest.version_view:type_name -> google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionView
	52, // 1: google.cloud.kms.v1.ListCryptoKeyVersionsRequest.view:type_name -> google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionView
	53, // 2: google.cloud.kms.v1.ListKeyRingsResponse.key_rings:type_name -> google.cloud.kms.v1.KeyRing
	54, // 3: google.cloud.kms.v1.ListCryptoKeysResponse.crypto_keys:type_name -> google.cloud.kms.v1.CryptoKey
	55, // 4: google.cloud.kms.v1.ListCryptoKeyVersionsResponse.crypto_key_versions:type_name -> google.cloud.kms.v1.CryptoKeyVersion
	56, // 5: google.cloud.kms.v1.ListImportJobsResponse.import_jobs:type_name -> google.cloud.kms.v1.ImportJob
	57, // 6: google.cloud.kms.v1.ListRetiredResourcesResponse.retired_resources:type_name -> google.cloud.kms.v1.RetiredResource
	58, // 7: google.cloud.kms.v1.GetPublicKeyRequest.public_key_format:type_name -> google.cloud.kms.v1.PublicKey.PublicKeyFormat
	58, // 8: google.cloud.kms.v1.GetImportJobRequest.public_key_format:type_name -> google.cloud.kms.v1.PublicKey.PublicKeyFormat
	53, // 9: google.cloud.kms.v1.CreateKeyRingRequest.key_ring:type_name -> google.cloud.kms.v1.KeyRing
	54, // 10: google.cloud.kms.v1.CreateCryptoKeyRequest.crypto_key:type_name -> google.cloud.kms.v1.CryptoKey
	55, // 11: google.cloud.kms.v1.CreateCryptoKeyVersionRequest.crypto_key_version:type_name -> google.cloud.kms.v1.CryptoKeyVersion
	59, // 12: google.cloud.kms.v1.ImportCryptoKeyVersionRequest.algorithm:type_name -> google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionAlgorithm
	56, // 13: google.cloud.kms.v1.CreateImportJobRequest.import_job:type_name -> google.cloud.kms.v1.ImportJob
	54, // 14: google.cloud.kms.v1.UpdateCryptoKeyRequest.crypto_key:type_name -> google.cloud.kms.v1.CryptoKey
	60, // 15: google.cloud.kms.v1.UpdateCryptoKeyRequest.update_mask:type_name -> google.protobuf.FieldMask
	55, // 16: google.cloud.kms.v1.UpdateCryptoKeyVersionRequest.crypto_key_version:type_name -> google.cloud.kms.v1.CryptoKeyVersion
	60, // 17: google.cloud.kms.v1.UpdateCryptoKeyVersionRequest.update_mask:type_name -> google.protobuf.FieldMask
	61, // 18: google.cloud.kms.v1.EncryptRequest.plaintext_crc32c:type_name -> google.protobuf.Int64Value
	61, // 19: google.cloud.kms.v1.EncryptRequest.additional_authenticated_data_crc32c:type_name -> google.protobuf.Int64Value
	61, // 20: google.cloud.kms.v1.DecryptRequest.ciphertext_crc32c:type_name -> google.protobuf.Int64Value
	61, // 21: google.cloud.kms.v1.DecryptRequest.additional_authenticated_data_crc32c:type_name -> google.protobuf.Int64Value
	61, // 22: google.cloud.kms.v1.RawEncryptRequest.plaintext_crc32c:type_name -> google.protobuf.Int64Value
	61, // 23: google.cloud.kms.v1.RawEncryptRequest.additional_authenticated_data_crc32c:type_name -> google.protobuf.Int64Value
	61, // 24: google.cloud.kms.v1.RawEncryptRequest.initialization_vector_crc32c:type_name -> google.protobuf.Int64Value
	61, // 25: google.cloud.kms.v1.RawDecryptRequest.ciphertext_crc32c:type_name -> google.protobuf.Int64Value
	61, // 26: google.cloud.kms.v1.RawDecryptRequest.additional_authenticated_data_crc32c:type_name -> google.protobuf.Int64Value
	61, // 27: google.cloud.kms.v1.RawDecryptRequest.initialization_vector_crc32c:type_name -> google.protobuf.Int64Value
	48, // 28: google.cloud.kms.v1.AsymmetricSignRequest.digest:type_name -> google.cloud.kms.v1.Digest
	61, // 29: google.cloud.kms.v1.AsymmetricSignRequest.digest_crc32c:type_name -> google.protobuf.Int64Value
	61, // 30: google.cloud.kms.v1.AsymmetricSignRequest.data_crc32c:type_name -> google.protobuf.Int64Value
	61, // 31: google.cloud.kms.v1.AsymmetricDecryptRequest.ciphertext_crc32c:type_name -> google.protobuf.Int64Value
	61, // 32: google.cloud.kms.v1.MacSignRequest.data_crc32c:type_name -> google.protobuf.Int64Value
	61, // 33: google.cloud.kms.v1.MacVerifyRequest.data_crc32c:type_name -> google.protobuf.Int64Value
	61, // 34: google.cloud.kms.v1.MacVerifyRequest.mac_crc32c:type_name -> google.protobuf.Int64Value
	61, // 35: google.cloud.kms.v1.DecapsulateRequest.ciphertext_crc32c:type_name -> google.protobuf.Int64Value
	62, // 36: google.cloud.kms.v1.GenerateRandomBytesRequest.protection_level:type_name -> google.cloud.kms.v1.ProtectionLevel
	61, // 37: google.cloud.kms.v1.EncryptResponse.ciphertext_crc32c:type_name -> google.protobuf.Int64Value
	62, // 38: google.cloud.kms.v1.EncryptResponse.protection_level:type_name -> google.cloud.kms.v1.ProtectionLevel
	61, // 39: google.cloud.kms.v1.DecryptResponse.plaintext_crc32c:type_name -> google.protobuf.Int64Value
	62, // 40: google.cloud.kms.v1.DecryptResponse.protection_level:type_name -> google.cloud.kms.v1.ProtectionLevel
	61, // 41: google.cloud.kms.v1.RawEncryptResponse.ciphertext_crc32c:type_name -> google.protobuf.Int64Value
	61, // 42: google.cloud.kms.v1.RawEncryptResponse.initialization_vector_crc32c:type_name -> google.protobuf.Int64Value
	62, // 43: google.cloud.kms.v1.RawEncryptResponse.protection_level:type_name -> google.cloud.kms.v1.ProtectionLevel
	61, // 44: google.cloud.kms.v1.RawDecryptResponse.plaintext_crc32c:type_name -> google.protobuf.Int64Value
	62, // 45: google.cloud.kms.v1.RawDecryptResponse.protection_level:type_name -> google.cloud.kms.v1.ProtectionLevel
	61, // 46: google.cloud.kms.v1.AsymmetricSignResponse.signature_crc32c:type_name -> google.protobuf.Int64Value
	62, // 47: google.cloud.kms.v1.AsymmetricSignResponse.protection_level:type_name -> google.cloud.kms.v1.ProtectionLevel
	61, // 48: google.cloud.kms.v1.AsymmetricDecryptResponse.plaintext_crc32c:type_name -> google.protobuf.Int64Value
	62, // 49: google.cloud.kms.v1.AsymmetricDecryptResponse.protection_level:type_name -> google.cloud.kms.v1.ProtectionLevel
	61, // 50: google.cloud.kms.v1.MacSignResponse.mac_crc32c:type_name -> google.protobuf.Int64Value
	62, // 51: google.cloud.kms.v1.MacSignResponse.protection_level:type_name -> google.cloud.kms.v1.ProtectionLevel
	62, // 52: google.cloud.kms.v1.MacVerifyResponse.protection_level:type_name -> google.cloud.kms.v1.ProtectionLevel
	62, // 53: google.cloud.kms.v1.DecapsulateResponse.protection_level:type_name -> google.cloud.kms.v1.ProtectionLevel
	61, // 54: google.cloud.kms.v1.GenerateRandomBytesResponse.data_crc32c:type_name -> google.protobuf.Int64Value
	0,  // 55: google.cloud.kms.v1.KeyManagementService.ListKeyRings:input_type -> google.cloud.kms.v1.ListKeyRingsRequest
	1,  // 56: google.cloud.kms.v1.KeyManagementService.ListCryptoKeys:input_type -> google.cloud.kms.v1.ListCryptoKeysRequest
	2,  // 57: google.cloud.kms.v1.KeyManagementService.ListCryptoKeyVersions:input_type -> google.cloud.kms.v1.ListCryptoKeyVersionsRequest
	3,  // 58: google.cloud.kms.v1.KeyManagementService.ListImportJobs:input_type -> google.cloud.kms.v1.ListImportJobsRequest
	4,  // 59: google.cloud.kms.v1.KeyManagementService.ListRetiredResources:input_type -> google.cloud.kms.v1.ListRetiredResourcesRequest
	10, // 60: google.cloud.kms.v1.KeyManagementService.GetKeyRing:input_type -> google.cloud.kms.v1.GetKeyRingRequest
	11, // 61: google.cloud.kms.v1.KeyManagementService.GetCryptoKey:input_type -> google.cloud.kms.v1.GetCryptoKeyRequest
	12, // 62: google.cloud.kms.v1.KeyManagementService.GetCryptoKeyVersion:input_type -> google.cloud.kms.v1.GetCryptoKeyVersionRequest
	13, // 63: google.cloud.kms.v1.KeyManagementService.GetPublicKey:input_type -> google.cloud.kms.v1.GetPublicKeyRequest
	14, // 64: google.cloud.kms.v1.KeyManagementService.GetImportJob:input_type -> google.cloud.kms.v1.GetImportJobRequest
	15, // 65: google.cloud.kms.v1.KeyManagementService.GetRetiredResource:input_type -> google.cloud.kms.v1.GetRetiredResourceRequest
	16, // 66: google.cloud.kms.v1.KeyManagementService.CreateKeyRing:input_type -> google.cloud.kms.v1.CreateKeyRingRequest
	17, // 67: google.cloud.kms.v1.KeyManagementService.CreateCryptoKey:input_type -> google.cloud.kms.v1.CreateCryptoKeyRequest
	18, // 68: google.cloud.kms.v1.KeyManagementService.CreateCryptoKeyVersion:input_type -> google.cloud.kms.v1.CreateCryptoKeyVersionRequest
	19, // 69: google.cloud.kms.v1.KeyManagementService.DeleteCryptoKey:input_type -> google.cloud.kms.v1.DeleteCryptoKeyRequest
	20, // 70: google.cloud.kms.v1.KeyManagementService.DeleteCryptoKeyVersion:input_type -> google.cloud.kms.v1.DeleteCryptoKeyVersionRequest
	21, // 71: google.cloud.kms.v1.KeyManagementService.ImportCryptoKeyVersion:input_type -> google.cloud.kms.v1.ImportCryptoKeyVersionRequest
	22, // 72: google.cloud.kms.v1.KeyManagementService.CreateImportJob:input_type -> google.cloud.kms.v1.CreateImportJobRequest
	23, // 73: google.cloud.kms.v1.KeyManagementService.UpdateCryptoKey:input_type -> google.cloud.kms.v1.UpdateCryptoKeyRequest
	24, // 74: google.cloud.kms.v1.KeyManagementService.UpdateCryptoKeyVersion:input_type -> google.cloud.kms.v1.UpdateCryptoKeyVersionRequest
	25, // 75: google.cloud.kms.v1.KeyManagementService.UpdateCryptoKeyPrimaryVersion:input_type -> google.cloud.kms.v1.UpdateCryptoKeyPrimaryVersionRequest
	26, // 76: google.cloud.kms.v1.KeyManagementService.DestroyCryptoKeyVersion:input_type -> google.cloud.kms.v1.DestroyCryptoKeyVersionRequest
	27, // 77: google.cloud.kms.v1.KeyManagementService.RestoreCryptoKeyVersion:input_type -> google.cloud.kms.v1.RestoreCryptoKeyVersionRequest
	28, // 78: google.cloud.kms.v1.KeyManagementService.Encrypt:input_type -> google.cloud.kms.v1.EncryptRequest
	29, // 79: google.cloud.kms.v1.KeyManagementService.Decrypt:input_type -> google.cloud.kms.v1.DecryptRequest
	30, // 80: google.cloud.kms.v1.KeyManagementService.RawEncrypt:input_type -> google.cloud.kms.v1.RawEncryptRequest
	31, // 81: google.cloud.kms.v1.KeyManagementService.RawDecrypt:input_type -> google.cloud.kms.v1.RawDecryptRequest
	32, // 82: google.cloud.kms.v1.KeyManagementService.AsymmetricSign:input_type -> google.cloud.kms.v1.AsymmetricSignRequest
	33, // 83: google.cloud.kms.v1.KeyManagementService.AsymmetricDecrypt:input_type -> google.cloud.kms.v1.AsymmetricDecryptRequest
	34, // 84: google.cloud.kms.v1.KeyManagementService.MacSign:input_type -> google.cloud.kms.v1.MacSignRequest
	35, // 85: google.cloud.kms.v1.KeyManagementService.MacVerify:input_type -> google.cloud.kms.v1.MacVerifyRequest
	36, // 86: google.cloud.kms.v1.KeyManagementService.Decapsulate:input_type -> google.cloud.kms.v1.DecapsulateRequest
	37, // 87: google.cloud.kms.v1.KeyManagementService.GenerateRandomBytes:input_type -> google.cloud.kms.v1.GenerateRandomBytesRequest
	5,  // 88: google.cloud.kms.v1.KeyManagementService.ListKeyRings:output_type -> google.cloud.kms.v1.ListKeyRingsResponse
	6,  // 89: google.cloud.kms.v1.KeyManagementService.ListCryptoKeys:output_type -> google.cloud.kms.v1.ListCryptoKeysResponse
	7,  // 90: google.cloud.kms.v1.KeyManagementService.ListCryptoKeyVersions:output_type -> google.cloud.kms.v1.ListCryptoKeyVersionsResponse
	8,  // 91: google.cloud.kms.v1.KeyManagementService.ListImportJobs:output_type -> google.cloud.kms.v1.ListImportJobsResponse
	9,  // 92: google.cloud.kms.v1.KeyManagementService.ListRetiredResources:output_type -> google.cloud.kms.v1.ListRetiredResourcesResponse
	53, // 93: google.cloud.kms.v1.KeyManagementService.GetKeyRing:output_type -> google.cloud.kms.v1.KeyRing
	54, // 94: google.cloud.kms.v1.KeyManagementService.GetCryptoKey:output_type -> google.cloud.kms.v1.CryptoKey
	55, // 95: google.cloud.kms.v1.KeyManagementService.GetCryptoKeyVersion:output_type -> google.cloud.kms.v1.CryptoKeyVersion
	63, // 96: google.cloud.kms.v1.KeyManagementService.GetPublicKey:output_type -> google.cloud.kms.v1.PublicKey
	56, // 97: google.cloud.kms.v1.KeyManagementService.GetImportJob:output_type -> google.cloud.kms.v1.ImportJob
	57, // 98: google.cloud.kms.v1.KeyManagementService.GetRetiredResource:output_type -> google.cloud.kms.v1.RetiredResource
	53, // 99: google.cloud.kms.v1.KeyManagementService.CreateKeyRing:output_type -> google.cloud.kms.v1.KeyRing
	54, // 100: google.cloud.kms.v1.KeyManagementService.CreateCryptoKey:output_type -> google.cloud.kms.v1.CryptoKey
	55, // 101: google.cloud.kms.v1.KeyManagementService.CreateCryptoKeyVersion:output_type -> google.cloud.kms.v1.CryptoKeyVersion
	64, // 102: google.cloud.kms.v1.KeyManagementService.DeleteCryptoKey:output_type -> google.longrunning.Operation
	64, // 103: google.cloud.kms.v1.KeyManagementService.DeleteCryptoKeyVersion:output_type -> google.longrunning.Operation
	55, // 104: google.cloud.kms.v1.KeyManagementService.ImportCryptoKeyVersion:output_type -> google.cloud.kms.v1.CryptoKeyVersion
	56, // 105: google.cloud.kms.v1.KeyManagementService.CreateImportJob:output_type -> google.cloud.kms.v1.ImportJob
	54, // 106: google.cloud.kms.v1.KeyManagementService.UpdateCryptoKey:output_type -> google.cloud.kms.v1.CryptoKey
	55, // 107: google.cloud.kms.v1.KeyManagementService.UpdateCryptoKeyVersion:output_type -> google.cloud.kms.v1.CryptoKeyVersion
	54, // 108: google.cloud.kms.v1.KeyManagementService.UpdateCryptoKeyPrimaryVersion:output_type -> google.cloud.kms.v1.CryptoKey
	55, // 109: google.cloud.kms.v1.KeyManagementService.DestroyCryptoKeyVersion:output_type -> google.cloud.kms.v1.CryptoKeyVersion
	55, // 110: google.cloud.kms.v1.KeyManagementService.RestoreCryptoKeyVersion:output_type -> google.cloud.kms.v1.CryptoKeyVersion
	38, // 111: google.cloud.kms.v1.KeyManagementService.Encrypt:output_type -> google.cloud.kms.v1.EncryptResponse
	39, // 112: google.cloud.kms.v1.KeyManagementService.Decrypt:output_type -> google.cloud.kms.v1.DecryptResponse
	40, // 113: google.cloud.kms.v1.KeyManagementService.RawEncrypt:output_type -> google.cloud.kms.v1.RawEncryptResponse
	41, // 114: google.cloud.kms.v1.KeyManagementService.RawDecrypt:output_type -> google.cloud.kms.v1.RawDecryptResponse
	42, // 115: google.cloud.kms.v1.KeyManagementService.AsymmetricSign:output_type -> google.cloud.kms.v1.AsymmetricSignResponse
	43, // 116: google.cloud.kms.v1.KeyManagementService.AsymmetricDecrypt:output_type -> google.cloud.kms.v1.AsymmetricDecryptResponse
	44, // 117: google.cloud.kms.v1.KeyManagementService.MacSign:output_type -> google.cloud.kms.v1.MacSignResponse
	45, // 118: google.cloud.kms.v1.KeyManagementService.MacVerify:output_type -> google.cloud.kms.v1.MacVerifyResponse
	46, // 119: google.cloud.kms.v1.KeyManagementService.Decapsulate:output_type -> google.cloud.kms.v1.DecapsulateResponse
	47, // 120: google.cloud.kms.v1.KeyManagementService.GenerateRandomBytes:output_type -> google.cloud.kms.v1.GenerateRandomBytesResponse
	88, // [88:121] is the sub-list for method output_type
	55, // [55:88] is the sub-list for method input_type
	55, // [55:55] is the sub-list for extension type_name
	55, // [55:55] is the sub-list for extension extendee
	0,  // [0:55] is the sub-list for field type_name
}

func init() { file_google_cloud_kms_v1_service_proto_init() }
func file_google_cloud_kms_v1_service_proto_init() {
	if File_google_cloud_kms_v1_service_proto != nil {
		return
	}
	file_google_cloud_kms_v1_resources_proto_init()
	file_google_cloud_kms_v1_service_proto_msgTypes[21].OneofWrappers = []any{
		(*ImportCryptoKeyVersionRequest_RsaAesWrappedKey)(nil),
	}
	file_google_cloud_kms_v1_service_proto_msgTypes[46].OneofWrappers = []any{}
	file_google_cloud_kms_v1_service_proto_msgTypes[48].OneofWrappers = []any{
		(*Digest_Sha256)(nil),
		(*Digest_Sha384)(nil),
		(*Digest_Sha512)(nil),
		(*Digest_ExternalMu)(nil),
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_google_cloud_kms_v1_service_proto_rawDesc), len(file_google_cloud_kms_v1_service_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   52,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_google_cloud_kms_v1_service_proto_goTypes,
		DependencyIndexes: file_google_cloud_kms_v1_service_proto_depIdxs,
		MessageInfos:      file_google_cloud_kms_v1_service_proto_msgTypes,
	}.Build()
	File_google_cloud_kms_v1_service_proto = out.File
	file_google_cloud_kms_v1_service_proto_goTypes = nil
	file_google_cloud_kms_v1_service_proto_depIdxs = nil
}
